# Copyright (C) 2023 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
from __future__ import annotations

from .events import (
    QAsyncioEventLoopPolicy, QAsyncioEventLoop, QAsyncioHandle, QAsyncioTimerHandle
)
from .futures import QAsyncioFuture
from .tasks import QAsyncioTask

from typing import Coroutine, Any

import asyncio

__all__ = [
    "QAsyncioEventLoopPolicy", "QAsyncioEventLoop",
    "QAsyncioHandle", "QAsyncioTimerHandle",
    "QAsyncioFuture", "QAsyncioTask"
]


def run(coro: Coroutine | None = None,
        keep_running: bool = True, quit_qapp: bool = True, *, handle_sigint: bool = False,
        debug: bool | None = None) -> Any:
    """
    Run the QtAsyncio event loop.

    If there is no instance of a QCoreApplication, QGuiApplication or
    QApplication yet, a new instance of QCoreApplication is created.

    :param coro:            The coroutine to run. Optional if keep_running is
                            True.
    :param keep_running:    If True, QtAsyncio (the asyncio event loop) will
                            continue running after the coroutine finished, or
                            run "forever" if no coroutine was provided.
                            If False, QtAsyncio will stop after the
                            coroutine finished. A coroutine must be provided if
                            this argument is set to False.
    :param quit_qapp:       If True, the QCoreApplication will quit when
                            QtAsyncio (the asyncio event loop) stops.
                            If False, the QCoreApplication will remain active
                            after QtAsyncio stops, and can continue to be used.
    :param handle_sigint:   If True, the SIGINT signal will be handled by the
                            event loop, causing it to stop.
    :param debug:           If True, the event loop will run in debug mode.
                            If False, the event loop will run in normal mode.
                            If None, the default behavior is used.
    """

    # Event loop policies are expected to be deprecated with Python 3.13, with
    # subsequent removal in Python 3.15. At that point, part of the current
    # logic of the QAsyncioEventLoopPolicy constructor will have to be moved
    # here and/or to a loop factory class (to be provided as an argument to
    # asyncio.run()). In particular, this concerns the logic of setting up the
    # QCoreApplication and the SIGINT handler.
    #
    # More details:
    # https://discuss.python.org/t/removing-the-asyncio-policy-system-asyncio-set-event-loop-policy-in-python-3-15/37553  # noqa: E501
    default_policy = asyncio.get_event_loop_policy()
    asyncio.set_event_loop_policy(
        QAsyncioEventLoopPolicy(quit_qapp=quit_qapp, handle_sigint=handle_sigint))

    ret = None
    exc = None

    if keep_running:
        if coro:
            asyncio.ensure_future(coro)
        asyncio.get_event_loop().run_forever()
    else:
        if coro:
            ret = asyncio.run(coro, debug=debug)
        else:
            exc = RuntimeError(
                "QtAsyncio was set not to keep running after the coroutine "
                "finished, but no coroutine was provided.")

    asyncio.set_event_loop_policy(default_policy)

    if ret:
        return ret
    if exc:
        raise exc



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtCanvasPainter, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtCanvasPainter`

import PySide6.QtCanvasPainter
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtWidgets
import PySide6.QtQuick

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QCanvasBoxGradient(PySide6.QtCanvasPainter.QCanvasGradient):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QCanvasBoxGradient: PySide6.QtCanvasPainter.QCanvasBoxGradient, /) -> None: ...
    @typing.overload
    def __init__(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, feather: float, /, radius: float = ...) -> None: ...
    @typing.overload
    def __init__(self, x: float, y: float, width: float, height: float, feather: float, /, radius: float = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def feather(self, /) -> float: ...
    def radius(self, /) -> float: ...
    def rect(self, /) -> PySide6.QtCore.QRectF: ...
    def setFeather(self, feather: float, /) -> None: ...
    def setRadius(self, radius: float, /) -> None: ...
    @typing.overload
    def setRect(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def setRect(self, x: float, y: float, width: float, height: float, /) -> None: ...


class QCanvasBoxShadow(PySide6.QtCanvasPainter.QCanvasBrush):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QCanvasBoxShadow: PySide6.QtCanvasPainter.QCanvasBoxShadow, /) -> None: ...
    @typing.overload
    def __init__(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /, radius: float = ..., blur: float = ..., color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int = ...) -> None: ...
    @typing.overload
    def __init__(self, x: float, y: float, width: float, height: float, /, radius: float = ..., blur: float = ..., color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtCanvasPainter.QCanvasBoxShadow | PySide6.QtCore.QRectF, /) -> bool: ...
    def __lshift__(self, arg__1: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def __ne__(self, rhs: PySide6.QtCanvasPainter.QCanvasBoxShadow | PySide6.QtCore.QRectF, /) -> bool: ...
    def __repr__(self, /) -> str: ...
    def __rshift__(self, arg__1: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def blur(self, /) -> float: ...
    def bottomLeftRadius(self, /) -> float: ...
    def bottomRightRadius(self, /) -> float: ...
    def boundingRect(self, /) -> PySide6.QtCore.QRectF: ...
    def color(self, /) -> PySide6.QtGui.QColor: ...
    def radius(self, /) -> float: ...
    def rect(self, /) -> PySide6.QtCore.QRectF: ...
    def setBlur(self, blur: float, /) -> None: ...
    def setBottomLeftRadius(self, radius: float, /) -> None: ...
    def setBottomRightRadius(self, radius: float, /) -> None: ...
    def setColor(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    def setRadius(self, radius: float, /) -> None: ...
    @typing.overload
    def setRect(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def setRect(self, x: float, y: float, width: float, height: float, /) -> None: ...
    def setSpread(self, spread: float, /) -> None: ...
    def setTopLeftRadius(self, radius: float, /) -> None: ...
    def setTopRightRadius(self, radius: float, /) -> None: ...
    def spread(self, /) -> float: ...
    def topLeftRadius(self, /) -> float: ...
    def topRightRadius(self, /) -> float: ...


class QCanvasBrush(Shiboken.Object):

    class BrushType(enum.Enum):

        Invalid                   = 0x0
        LinearGradient            = 0x1
        RadialGradient            = 0x2
        ConicalGradient           = 0x3
        BoxGradient               = 0x4
        BoxShadow                 = 0x5
        ImagePattern              = 0x6
        GridPattern               = 0x7
        Custom                    = 0x3e8


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, brush: PySide6.QtCanvasPainter.QCanvasBrush, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __repr__(self, /) -> str: ...
    def swap(self, other: PySide6.QtCanvasPainter.QCanvasBrush, /) -> None: ...
    def type(self, /) -> PySide6.QtCanvasPainter.QCanvasBrush.BrushType: ...


class QCanvasConicalGradient(PySide6.QtCanvasPainter.QCanvasGradient):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QCanvasConicalGradient: PySide6.QtCanvasPainter.QCanvasConicalGradient, /) -> None: ...
    @typing.overload
    def __init__(self, center: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, startAngle: float, /) -> None: ...
    @typing.overload
    def __init__(self, centerX: float, centerY: float, startAngle: float, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def angle(self, /) -> float: ...
    def centerPosition(self, /) -> PySide6.QtCore.QPointF: ...
    def setAngle(self, angle: float, /) -> None: ...
    @typing.overload
    def setCenterPosition(self, center: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def setCenterPosition(self, x: float, y: float, /) -> None: ...


class QCanvasCustomBrush(PySide6.QtCanvasPainter.QCanvasBrush):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QCanvasCustomBrush: PySide6.QtCanvasPainter.QCanvasCustomBrush, /) -> None: ...
    @typing.overload
    def __init__(self, fragmentShader: str, /, vertexShader: str = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtCanvasPainter.QCanvasCustomBrush | str, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtCanvasPainter.QCanvasCustomBrush | str, /) -> bool: ...
    def __repr__(self, /) -> str: ...
    def setData1(self, data: PySide6.QtGui.QVector4D, /) -> None: ...
    def setData2(self, data: PySide6.QtGui.QVector4D, /) -> None: ...
    def setData3(self, data: PySide6.QtGui.QVector4D, /) -> None: ...
    def setData4(self, data: PySide6.QtGui.QVector4D, /) -> None: ...
    @typing.overload
    def setFragmentShader(self, fragmentShader: PySide6.QtGui.QShader, /) -> None: ...
    @typing.overload
    def setFragmentShader(self, fragmentShader: str, /) -> None: ...
    def setTimeRunning(self, running: bool, /) -> None: ...
    @typing.overload
    def setVertexShader(self, vertexShader: PySide6.QtGui.QShader, /) -> None: ...
    @typing.overload
    def setVertexShader(self, vertexShader: str, /) -> None: ...
    def timeRunning(self, /) -> bool: ...


class QCanvasGradient(PySide6.QtCanvasPainter.QCanvasBrush):

    def __init__(self, QCanvasGradient: PySide6.QtCanvasPainter.QCanvasGradient, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtCanvasPainter.QCanvasGradient, /) -> bool: ...
    def __lshift__(self, arg__1: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def __ne__(self, rhs: PySide6.QtCanvasPainter.QCanvasGradient, /) -> bool: ...
    def __repr__(self, /) -> str: ...
    def __rshift__(self, arg__1: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def endColor(self, /) -> PySide6.QtGui.QColor: ...
    def setColorAt(self, position: float, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    def setEndColor(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    def setStartColor(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    def startColor(self, /) -> PySide6.QtGui.QColor: ...
    def type(self, /) -> PySide6.QtCanvasPainter.QCanvasBrush.BrushType: ...


class QCanvasGridPattern(PySide6.QtCanvasPainter.QCanvasBrush):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QCanvasGridPattern: PySide6.QtCanvasPainter.QCanvasGridPattern, /) -> None: ...
    @typing.overload
    def __init__(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /, lineColor: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int = ..., backgroundColor: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int = ..., lineWidth: float = ..., feather: float = ..., angle: float = ...) -> None: ...
    @typing.overload
    def __init__(self, x: float, y: float, width: float, height: float, /, lineColor: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int = ..., backgroundColor: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int = ..., lineWidth: float = ..., feather: float = ..., angle: float = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtCanvasPainter.QCanvasGridPattern | PySide6.QtCore.QRectF, /) -> bool: ...
    def __lshift__(self, arg__1: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def __ne__(self, rhs: PySide6.QtCanvasPainter.QCanvasGridPattern | PySide6.QtCore.QRectF, /) -> bool: ...
    def __repr__(self, /) -> str: ...
    def __rshift__(self, arg__1: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def backgroundColor(self, /) -> PySide6.QtGui.QColor: ...
    def cellSize(self, /) -> PySide6.QtCore.QSizeF: ...
    def feather(self, /) -> float: ...
    def lineColor(self, /) -> PySide6.QtGui.QColor: ...
    def lineWidth(self, /) -> float: ...
    def rotation(self, /) -> float: ...
    def setBackgroundColor(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    @typing.overload
    def setCellSize(self, size: PySide6.QtCore.QSizeF | PySide6.QtCore.QSize, /) -> None: ...
    @typing.overload
    def setCellSize(self, width: float, height: float, /) -> None: ...
    def setFeather(self, feather: float, /) -> None: ...
    def setLineColor(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    def setLineWidth(self, width: float, /) -> None: ...
    def setRotation(self, rotation: float, /) -> None: ...
    @typing.overload
    def setStartPosition(self, point: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def setStartPosition(self, x: float, y: float, /) -> None: ...
    def startPosition(self, /) -> PySide6.QtCore.QPointF: ...


class QCanvasImage(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, image: PySide6.QtCanvasPainter.QCanvasImage, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtCanvasPainter.QCanvasImage, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtCanvasPainter.QCanvasImage, /) -> bool: ...
    def __repr__(self, /) -> str: ...
    def height(self, /) -> int: ...
    def id(self, /) -> int: ...
    def isNull(self, /) -> bool: ...
    def setTintColor(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    def size(self, /) -> PySide6.QtCore.QSize: ...
    def sizeInBytes(self, /) -> int: ...
    def swap(self, other: PySide6.QtCanvasPainter.QCanvasImage, /) -> None: ...
    def tintColor(self, /) -> PySide6.QtGui.QColor: ...
    def width(self, /) -> int: ...


class QCanvasImagePattern(PySide6.QtCanvasPainter.QCanvasBrush):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QCanvasImagePattern: PySide6.QtCanvasPainter.QCanvasImagePattern, /) -> None: ...
    @typing.overload
    def __init__(self, image: PySide6.QtCanvasPainter.QCanvasImage, /) -> None: ...
    @typing.overload
    def __init__(self, image: PySide6.QtCanvasPainter.QCanvasImage, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /, angle: float = ..., tintColor: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int = ...) -> None: ...
    @typing.overload
    def __init__(self, image: PySide6.QtCanvasPainter.QCanvasImage, x: float, y: float, width: float, height: float, /, angle: float = ..., tintColor: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtCanvasPainter.QCanvasImagePattern | PySide6.QtCanvasPainter.QCanvasImage, /) -> bool: ...
    def __lshift__(self, arg__1: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def __ne__(self, rhs: PySide6.QtCanvasPainter.QCanvasImagePattern | PySide6.QtCanvasPainter.QCanvasImage, /) -> bool: ...
    def __repr__(self, /) -> str: ...
    def __rshift__(self, arg__1: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def image(self, /) -> PySide6.QtCanvasPainter.QCanvasImage: ...
    def imageSize(self, /) -> PySide6.QtCore.QSizeF: ...
    def rotation(self, /) -> float: ...
    def setImage(self, image: PySide6.QtCanvasPainter.QCanvasImage, /) -> None: ...
    @typing.overload
    def setImageSize(self, size: PySide6.QtCore.QSizeF | PySide6.QtCore.QSize, /) -> None: ...
    @typing.overload
    def setImageSize(self, width: float, height: float, /) -> None: ...
    def setRotation(self, rotation: float, /) -> None: ...
    @typing.overload
    def setStartPosition(self, point: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def setStartPosition(self, x: float, y: float, /) -> None: ...
    def setTintColor(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    def startPosition(self, /) -> PySide6.QtCore.QPointF: ...
    def tintColor(self, /) -> PySide6.QtGui.QColor: ...


class QCanvasLinearGradient(PySide6.QtCanvasPainter.QCanvasGradient):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QCanvasLinearGradient: PySide6.QtCanvasPainter.QCanvasLinearGradient, /) -> None: ...
    @typing.overload
    def __init__(self, start: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, end: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def __init__(self, startX: float, startY: float, endX: float, endY: float, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def endPosition(self, /) -> PySide6.QtCore.QPointF: ...
    @typing.overload
    def setEndPosition(self, end: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def setEndPosition(self, x: float, y: float, /) -> None: ...
    @typing.overload
    def setStartPosition(self, start: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def setStartPosition(self, x: float, y: float, /) -> None: ...
    def startPosition(self, /) -> PySide6.QtCore.QPointF: ...


class QCanvasOffscreenCanvas(Shiboken.Object):

    class Flag(enum.Flag):

        PreserveContents          = 0x1
        MipMaps                   = 0x2


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, canvas: PySide6.QtCanvasPainter.QCanvasOffscreenCanvas, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtCanvasPainter.QCanvasOffscreenCanvas, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtCanvasPainter.QCanvasOffscreenCanvas, /) -> bool: ...
    def fillColor(self, /) -> PySide6.QtGui.QColor: ...
    def flags(self, /) -> PySide6.QtCanvasPainter.QCanvasOffscreenCanvas.Flag: ...
    def isNull(self, /) -> bool: ...
    def setFillColor(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    def swap(self, other: PySide6.QtCanvasPainter.QCanvasOffscreenCanvas, /) -> None: ...
    def texture(self, /) -> PySide6.QtGui.QRhiTexture: ...


class QCanvasPainter(Shiboken.Object):

    class CompositeOperation(enum.Enum):

        SourceOver                = 0x0
        SourceAtop                = 0x1
        DestinationOut            = 0x2

    class ImageFlag(enum.Flag):

        GenerateMipmaps           = 0x1
        RepeatX                   = 0x2
        RepeatY                   = 0x4
        Repeat                    = 0x6
        FlipY                     = 0x8
        Premultiplied             = 0x10
        Nearest                   = 0x20
        NativeTexture             = 0x40

    class LineCap(enum.Enum):

        Butt                      = 0x0
        Round                     = 0x1
        Square                    = 0x2

    class LineJoin(enum.Enum):

        Round                     = 0x0
        Bevel                     = 0x1
        Miter                     = 0x2

    class PathConnection(enum.Enum):

        NotConnected              = 0x0
        Connected                 = 0x1

    class PathWinding(enum.Enum):

        CounterClockWise          = 0x0
        ClockWise                 = 0x1

    class RenderHint(enum.Flag):

        Antialiasing              = 0x1
        HighQualityStroking       = 0x2
        DisableWindingEnforce     = 0x4

    class TextAlign(enum.Enum):

        Left                      = 0x0
        Right                     = 0x1
        Center                    = 0x2
        Start                     = 0x3
        End                       = 0x4

    class TextBaseline(enum.Enum):

        Top                       = 0x0
        Hanging                   = 0x1
        Middle                    = 0x2
        Alphabetic                = 0x3
        Bottom                    = 0x4

    class TextDirection(enum.Enum):

        LeftToRight               = 0x0
        RightToLeft               = 0x1
        Inherit                   = 0x2
        Auto                      = 0x3

    class WrapMode(enum.Enum):

        NoWrap                    = 0x0
        Wrap                      = 0x1
        WordWrap                  = 0x2
        WrapAnywhere              = 0x3


    def __init__(self, /) -> None: ...

    def activeImageCount(self, /) -> int: ...
    def activeImageMemoryUsage(self, /) -> int: ...
    @typing.overload
    def addImage(self, image: PySide6.QtGui.QImage, /, flags: PySide6.QtCanvasPainter.QCanvasPainter.ImageFlag = ...) -> PySide6.QtCanvasPainter.QCanvasImage: ...
    @typing.overload
    def addImage(self, texture: PySide6.QtGui.QRhiTexture, /, flags: PySide6.QtCanvasPainter.QCanvasPainter.ImageFlag = ...) -> PySide6.QtCanvasPainter.QCanvasImage: ...
    @typing.overload
    def addImage(self, canvas: PySide6.QtCanvasPainter.QCanvasOffscreenCanvas, /, flags: PySide6.QtCanvasPainter.QCanvasPainter.ImageFlag = ...) -> PySide6.QtCanvasPainter.QCanvasImage: ...
    @typing.overload
    def addPath(self, path: PySide6.QtGui.QPainterPath, /) -> None: ...
    @typing.overload
    def addPath(self, path: PySide6.QtCanvasPainter.QCanvasPath | int, /, transform: PySide6.QtGui.QTransform = ...) -> None: ...
    @typing.overload
    def addPath(self, path: PySide6.QtCanvasPainter.QCanvasPath | int, start: int, count: int, /, transform: PySide6.QtGui.QTransform = ...) -> None: ...
    @typing.overload
    def arc(self, centerPoint: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, radius: float, a0: float, a1: float, /, direction: PySide6.QtCanvasPainter.QCanvasPainter.PathWinding = ..., connection: PySide6.QtCanvasPainter.QCanvasPainter.PathConnection = ...) -> None: ...
    @typing.overload
    def arc(self, centerX: float, centerY: float, radius: float, a0: float, a1: float, /, direction: PySide6.QtCanvasPainter.QCanvasPainter.PathWinding = ..., connection: PySide6.QtCanvasPainter.QCanvasPainter.PathConnection = ...) -> None: ...
    @typing.overload
    def arcTo(self, controlPoint1: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, controlPoint2: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, radius: float, /) -> None: ...
    @typing.overload
    def arcTo(self, x1: float, y1: float, x2: float, y2: float, radius: float, /) -> None: ...
    def beginHoleSubPath(self, /) -> None: ...
    def beginPath(self, /) -> None: ...
    def beginSolidSubPath(self, /) -> None: ...
    @typing.overload
    def bezierCurveTo(self, controlPoint1: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, controlPoint2: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, endPoint: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def bezierCurveTo(self, cp1X: float, cp1Y: float, cp2X: float, cp2Y: float, x: float, y: float, /) -> None: ...
    @typing.overload
    def circle(self, centerPoint: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, radius: float, /) -> None: ...
    @typing.overload
    def circle(self, centerX: float, centerY: float, radius: float, /) -> None: ...
    def cleanupResources(self, /) -> None: ...
    @typing.overload
    def clearRect(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def clearRect(self, x: float, y: float, width: float, height: float, /) -> None: ...
    def closePath(self, /) -> None: ...
    def createCanvas(self, pixelSize: PySide6.QtCore.QSize, /, sampleCount: int = ..., flags: PySide6.QtCanvasPainter.QCanvasOffscreenCanvas.Flag = ...) -> PySide6.QtCanvasPainter.QCanvasOffscreenCanvas: ...
    def destroyCanvas(self, canvas: PySide6.QtCanvasPainter.QCanvasOffscreenCanvas, /) -> None: ...
    def devicePixelRatio(self, /) -> float: ...
    def drawBoxShadow(self, shadow: PySide6.QtCanvasPainter.QCanvasBoxShadow | PySide6.QtCore.QRectF, /) -> None: ...
    @typing.overload
    def drawImage(self, image: PySide6.QtCanvasPainter.QCanvasImage, destinationRect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def drawImage(self, image: PySide6.QtCanvasPainter.QCanvasImage, sourceRect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, destinationRect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def drawImage(self, image: PySide6.QtCanvasPainter.QCanvasImage, x: float, y: float, /) -> None: ...
    @typing.overload
    def drawImage(self, image: PySide6.QtCanvasPainter.QCanvasImage, x: float, y: float, width: float, height: float, /) -> None: ...
    @typing.overload
    def ellipse(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def ellipse(self, centerPoint: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, radiusX: float, radiusY: float, /) -> None: ...
    @typing.overload
    def ellipse(self, centerX: float, centerY: float, radiusX: float, radiusY: float, /) -> None: ...
    @typing.overload
    def fill(self, /) -> None: ...
    @typing.overload
    def fill(self, path: PySide6.QtCanvasPainter.QCanvasPath | int, /, pathGroup: int = ...) -> None: ...
    @typing.overload
    def fillRect(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def fillRect(self, x: float, y: float, width: float, height: float, /) -> None: ...
    @typing.overload
    def fillText(self, text: str, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def fillText(self, text: str, point: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /, maxWidth: float = ...) -> None: ...
    @typing.overload
    def fillText(self, text: str, x: float, y: float, /, maxWidth: float = ...) -> None: ...
    def getTransform(self, /) -> PySide6.QtGui.QTransform: ...
    @typing.overload
    def lineTo(self, point: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def lineTo(self, x: float, y: float, /) -> None: ...
    @staticmethod
    def mmToPx(mm: float, /) -> float: ...
    @typing.overload
    def moveTo(self, point: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def moveTo(self, x: float, y: float, /) -> None: ...
    @staticmethod
    def ptToPx(pt: float, /) -> float: ...
    @typing.overload
    def quadraticCurveTo(self, controlPoint: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, endPoint: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def quadraticCurveTo(self, cpX: float, cpY: float, x: float, y: float, /) -> None: ...
    @typing.overload
    def rect(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def rect(self, x: float, y: float, width: float, height: float, /) -> None: ...
    def removeImage(self, image: PySide6.QtCanvasPainter.QCanvasImage, /) -> None: ...
    def removePathGroup(self, pathGroup: int, /) -> None: ...
    def renderHints(self, /) -> PySide6.QtCanvasPainter.QCanvasPainter.RenderHint: ...
    def reset(self, /) -> None: ...
    def resetClipping(self, /) -> None: ...
    def resetTransform(self, /) -> None: ...
    def restore(self, /) -> None: ...
    def rotate(self, angle: float, /) -> None: ...
    @typing.overload
    def roundRect(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, radius: float, /) -> None: ...
    @typing.overload
    def roundRect(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, radiusTopLeft: float, radiusTopRight: float, radiusBottomRight: float, radiusBottomLeft: float, /) -> None: ...
    @typing.overload
    def roundRect(self, x: float, y: float, width: float, height: float, radius: float, /) -> None: ...
    @typing.overload
    def roundRect(self, x: float, y: float, width: float, height: float, radiusTopLeft: float, radiusTopRight: float, radiusBottomRight: float, radiusBottomLeft: float, /) -> None: ...
    def save(self, /) -> None: ...
    @typing.overload
    def scale(self, scale: float, /) -> None: ...
    @typing.overload
    def scale(self, scaleX: float, scaleY: float, /) -> None: ...
    def setAntialias(self, antialias: float, /) -> None: ...
    def setBrushTransform(self, transform: PySide6.QtGui.QTransform, /) -> None: ...
    @typing.overload
    def setClipRect(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def setClipRect(self, x: float, y: float, width: float, height: float, /) -> None: ...
    @typing.overload
    def setFillStyle(self, brush: PySide6.QtCanvasPainter.QCanvasBrush, /) -> None: ...
    @typing.overload
    def setFillStyle(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    def setFont(self, font: PySide6.QtGui.QFont | str | collections.abc.Sequence[str], /) -> None: ...
    def setGlobalAlpha(self, alpha: float, /) -> None: ...
    def setGlobalBrightness(self, value: float, /) -> None: ...
    def setGlobalCompositeOperation(self, operation: PySide6.QtCanvasPainter.QCanvasPainter.CompositeOperation, /) -> None: ...
    def setGlobalContrast(self, value: float, /) -> None: ...
    def setGlobalSaturate(self, value: float, /) -> None: ...
    def setLineCap(self, cap: PySide6.QtCanvasPainter.QCanvasPainter.LineCap, /) -> None: ...
    def setLineJoin(self, join: PySide6.QtCanvasPainter.QCanvasPainter.LineJoin, /) -> None: ...
    def setLineWidth(self, width: float, /) -> None: ...
    def setMiterLimit(self, limit: float, /) -> None: ...
    def setPathWinding(self, winding: PySide6.QtCanvasPainter.QCanvasPainter.PathWinding, /) -> None: ...
    def setRenderHint(self, hint: PySide6.QtCanvasPainter.QCanvasPainter.RenderHint, /, on: bool = ...) -> None: ...
    def setRenderHints(self, hints: PySide6.QtCanvasPainter.QCanvasPainter.RenderHint, /, on: bool = ...) -> None: ...
    @typing.overload
    def setStrokeStyle(self, brush: PySide6.QtCanvasPainter.QCanvasBrush, /) -> None: ...
    @typing.overload
    def setStrokeStyle(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    def setTextAlign(self, align: PySide6.QtCanvasPainter.QCanvasPainter.TextAlign, /) -> None: ...
    def setTextAntialias(self, antialias: float, /) -> None: ...
    def setTextBaseline(self, baseline: PySide6.QtCanvasPainter.QCanvasPainter.TextBaseline, /) -> None: ...
    def setTextDirection(self, direction: PySide6.QtCanvasPainter.QCanvasPainter.TextDirection, /) -> None: ...
    def setTextLineHeight(self, height: float, /) -> None: ...
    def setTextWrapMode(self, wrapMode: PySide6.QtCanvasPainter.QCanvasPainter.WrapMode, /) -> None: ...
    def setTransform(self, transform: PySide6.QtGui.QTransform, /) -> None: ...
    def skew(self, angleX: float, /, angleY: float = ...) -> None: ...
    @typing.overload
    def stroke(self, /) -> None: ...
    @typing.overload
    def stroke(self, path: PySide6.QtCanvasPainter.QCanvasPath | int, /, pathGroup: int = ...) -> None: ...
    @typing.overload
    def strokeRect(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def strokeRect(self, x: float, y: float, width: float, height: float, /) -> None: ...
    @typing.overload
    def textBoundingBox(self, text: str, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> PySide6.QtCore.QRectF: ...
    @typing.overload
    def textBoundingBox(self, text: str, point: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /, maxWidth: float = ...) -> PySide6.QtCore.QRectF: ...
    @typing.overload
    def textBoundingBox(self, text: str, x: float, y: float, /, maxWidth: float = ...) -> PySide6.QtCore.QRectF: ...
    def transform(self, transform: PySide6.QtGui.QTransform, /) -> None: ...
    @typing.overload
    def translate(self, point: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def translate(self, x: float, y: float, /) -> None: ...


class QCanvasPainterFactory(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def create(self, rhi: PySide6.QtGui.QRhi, /) -> PySide6.QtCanvasPainter.QCanvasPainter: ...
    def destroy(self, /) -> None: ...
    def isValid(self, /) -> bool: ...
    def paintDriver(self, /) -> PySide6.QtCanvasPainter.QCanvasRhiPaintDriver: ...
    def painter(self, /) -> PySide6.QtCanvasPainter.QCanvasPainter: ...
    @staticmethod
    def sharedInstance(rhi: PySide6.QtGui.QRhi, /) -> PySide6.QtCanvasPainter.QCanvasPainterFactory: ...


class QCanvasPainterItem(PySide6.QtQuick.QQuickRhiItem):

    debugChanged             : typing.ClassVar[Signal] = ... # debugChanged()
    fillColorChanged         : typing.ClassVar[Signal] = ... # fillColorChanged()

    def __init__(self, /, parent: PySide6.QtQuick.QQuickItem | None = ..., *, fillColor: PySide6.QtGui.QColor | None = ..., debug: typing.Dict[str, typing.Any] | None = ...) -> None: ...

    def createItemRenderer(self, /) -> PySide6.QtCanvasPainter.QCanvasPainterItemRenderer: ...
    def createRenderer(self, /) -> PySide6.QtQuick.QQuickRhiItemRenderer: ...
    def debug(self, /) -> typing.Dict[str, typing.Any]: ...
    def fillColor(self, /) -> PySide6.QtGui.QColor: ...
    def setFillColor(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...


class QCanvasPainterItemRenderer(PySide6.QtQuick.QQuickRhiItemRenderer):

    def __init__(self, /) -> None: ...

    def beginCanvasPainting(self, canvas: PySide6.QtCanvasPainter.QCanvasOffscreenCanvas, /) -> None: ...
    def endCanvasPainting(self, /) -> None: ...
    def fillColor(self, /) -> PySide6.QtGui.QColor: ...
    def hasSharedPainter(self, /) -> bool: ...
    def height(self, /) -> float: ...
    def initialize(self, cb: PySide6.QtGui.QRhiCommandBuffer, /) -> None: ...
    def initializeResources(self, painter: PySide6.QtCanvasPainter.QCanvasPainter, /) -> None: ...
    def paint(self, painter: PySide6.QtCanvasPainter.QCanvasPainter, /) -> None: ...
    def painter(self, /) -> PySide6.QtCanvasPainter.QCanvasPainter: ...
    def prePaint(self, painter: PySide6.QtCanvasPainter.QCanvasPainter, /) -> None: ...
    def render(self, cb: PySide6.QtGui.QRhiCommandBuffer, /) -> None: ...
    def setSharedPainter(self, enable: bool, /) -> None: ...
    @typing.overload
    def synchronize(self, item: PySide6.QtCanvasPainter.QCanvasPainterItem, /) -> None: ...
    @typing.overload
    def synchronize(self, item: PySide6.QtQuick.QQuickRhiItem, /) -> None: ...
    def synchronizeData(self, item: PySide6.QtCanvasPainter.QCanvasPainterItem, /) -> None: ...
    def width(self, /) -> float: ...


class QCanvasPainterWidget(PySide6.QtWidgets.QRhiWidget):

    def __init__(self, /, parent: PySide6.QtWidgets.QWidget | None = ...) -> None: ...

    def beginCanvasPainting(self, canvas: PySide6.QtCanvasPainter.QCanvasOffscreenCanvas, /) -> None: ...
    def endCanvasPainting(self, /) -> None: ...
    def fillColor(self, /) -> PySide6.QtGui.QColor: ...
    def grabCanvas(self, canvas: PySide6.QtCanvasPainter.QCanvasOffscreenCanvas, resultCallback: collections.abc.Callable[..., typing.Any], /) -> None: ...
    def graphicsResourcesInvalidated(self, /) -> None: ...
    def hasSharedPainter(self, /) -> bool: ...
    def initialize(self, cb: PySide6.QtGui.QRhiCommandBuffer, /) -> None: ...
    def initializeResources(self, painter: PySide6.QtCanvasPainter.QCanvasPainter, /) -> None: ...
    def paint(self, painter: PySide6.QtCanvasPainter.QCanvasPainter, /) -> None: ...
    def prePaint(self, painter: PySide6.QtCanvasPainter.QCanvasPainter, /) -> None: ...
    def releaseResources(self, /) -> None: ...
    @typing.overload
    def render(self, cb: PySide6.QtGui.QRhiCommandBuffer, /) -> None: ...
    @typing.overload
    def render(self, target: PySide6.QtGui.QPaintDevice, /, targetOffset: PySide6.QtCore.QPoint = ..., sourceRegion: PySide6.QtGui.QRegion | PySide6.QtGui.QBitmap | PySide6.QtGui.QPolygon | PySide6.QtCore.QRect = ..., renderFlags: PySide6.QtWidgets.QWidget.RenderFlag = ...) -> None: ...
    @typing.overload
    def render(self, painter: PySide6.QtGui.QPainter, targetOffset: PySide6.QtCore.QPoint, /, sourceRegion: PySide6.QtGui.QRegion | PySide6.QtGui.QBitmap | PySide6.QtGui.QPolygon | PySide6.QtCore.QRect = ..., renderFlags: PySide6.QtWidgets.QWidget.RenderFlag = ...) -> None: ...
    def setFillColor(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
    def setSharedPainter(self, enable: bool, /) -> None: ...


class QCanvasPath(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, path: PySide6.QtCanvasPainter.QCanvasPath, /) -> None: ...
    @typing.overload
    def __init__(self, commandsSize: int, /, commandsDataSize: int = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtCanvasPainter.QCanvasPath | int, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtCanvasPainter.QCanvasPath | int, /) -> bool: ...
    @typing.overload
    def addPath(self, path: PySide6.QtCanvasPainter.QCanvasPath | int, /, transform: PySide6.QtGui.QTransform = ...) -> None: ...
    @typing.overload
    def addPath(self, path: PySide6.QtCanvasPainter.QCanvasPath | int, start: int, count: int, /, transform: PySide6.QtGui.QTransform = ...) -> None: ...
    @typing.overload
    def arc(self, centerPoint: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, radius: float, a0: float, a1: float, /, direction: PySide6.QtCanvasPainter.QCanvasPainter.PathWinding = ..., connection: PySide6.QtCanvasPainter.QCanvasPainter.PathConnection = ...) -> None: ...
    @typing.overload
    def arc(self, centerX: float, centerY: float, radius: float, a0: float, a1: float, /, direction: PySide6.QtCanvasPainter.QCanvasPainter.PathWinding = ..., connection: PySide6.QtCanvasPainter.QCanvasPainter.PathConnection = ...) -> None: ...
    @typing.overload
    def arcTo(self, controlPoint1: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, controlPoint2: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, radius: float, /) -> None: ...
    @typing.overload
    def arcTo(self, c1x: float, c1y: float, c2x: float, c2y: float, radius: float, /) -> None: ...
    def beginHoleSubPath(self, /) -> None: ...
    def beginSolidSubPath(self, /) -> None: ...
    @typing.overload
    def bezierCurveTo(self, controlPoint1: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, controlPoint2: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, endPoint: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def bezierCurveTo(self, c1x: float, c1y: float, c2x: float, c2y: float, x: float, y: float, /) -> None: ...
    @typing.overload
    def circle(self, centerPoint: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, radius: float, /) -> None: ...
    @typing.overload
    def circle(self, x: float, y: float, radius: float, /) -> None: ...
    def clear(self, /) -> None: ...
    def closePath(self, /) -> None: ...
    def commandsCapacity(self, /) -> int: ...
    def commandsDataCapacity(self, /) -> int: ...
    def commandsDataSize(self, /) -> int: ...
    def commandsSize(self, /) -> int: ...
    def currentPosition(self, /) -> PySide6.QtCore.QPointF: ...
    @typing.overload
    def ellipse(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def ellipse(self, x: float, y: float, radiusX: float, radiusY: float, /) -> None: ...
    def isEmpty(self, /) -> bool: ...
    @typing.overload
    def lineTo(self, point: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def lineTo(self, x: float, y: float, /) -> None: ...
    @typing.overload
    def moveTo(self, point: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def moveTo(self, x: float, y: float, /) -> None: ...
    def positionAt(self, index: int, /) -> PySide6.QtCore.QPointF: ...
    @typing.overload
    def quadraticCurveTo(self, controlPoint: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, endPoint: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def quadraticCurveTo(self, cx: float, cy: float, x: float, y: float, /) -> None: ...
    @typing.overload
    def rect(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
    @typing.overload
    def rect(self, x: float, y: float, width: float, height: float, /) -> None: ...
    @typing.overload
    def reserve(self, commandsSize: int, /) -> None: ...
    @typing.overload
    def reserve(self, commandsSize: int, commandsDataSize: int, /) -> None: ...
    @typing.overload
    def roundRect(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, radius: float, /) -> None: ...
    @typing.overload
    def roundRect(self, rect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, radiusTopLeft: float, radiusTopRight: float, radiusBottomRight: float, radiusBottomLeft: float, /) -> None: ...
    @typing.overload
    def roundRect(self, x: float, y: float, width: float, height: float, radius: float, /) -> None: ...
    @typing.overload
    def roundRect(self, x: float, y: float, width: float, height: float, radiusTopLeft: float, radiusTopRight: float, radiusBottomRight: float, radiusBottomLeft: float, /) -> None: ...
    def setPathWinding(self, winding: PySide6.QtCanvasPainter.QCanvasPainter.PathWinding, /) -> None: ...
    def sliced(self, start: int, count: int, /, transform: PySide6.QtGui.QTransform = ...) -> PySide6.QtCanvasPainter.QCanvasPath: ...
    def squeeze(self, /) -> None: ...
    def swap(self, other: PySide6.QtCanvasPainter.QCanvasPath | int, /) -> None: ...


class QCanvasRadialGradient(PySide6.QtCanvasPainter.QCanvasGradient):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QCanvasRadialGradient: PySide6.QtCanvasPainter.QCanvasRadialGradient, /) -> None: ...
    @typing.overload
    def __init__(self, center: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, outerRadius: float, /, innerRadius: float = ...) -> None: ...
    @typing.overload
    def __init__(self, centerX: float, centerY: float, outerRadius: float, /, innerRadius: float = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def centerPosition(self, /) -> PySide6.QtCore.QPointF: ...
    def innerRadius(self, /) -> float: ...
    def outerRadius(self, /) -> float: ...
    @typing.overload
    def setCenterPosition(self, center: PySide6.QtCore.QPointF | PySide6.QtCore.QPoint | PySide6.QtGui.QPainterPath.Element, /) -> None: ...
    @typing.overload
    def setCenterPosition(self, x: float, y: float, /) -> None: ...
    def setInnerRadius(self, radius: float, /) -> None: ...
    def setOuterRadius(self, radius: float, /) -> None: ...


class QCanvasRhiPaintDriver(Shiboken.Object):

    class BeginPaintFlag(enum.Flag):

        DepthTest                 = 0x1

    class EndPaintFlag(enum.Flag):

        DoNotRecordRenderPass     = 0x1


    def __init__(self, /) -> None: ...

    @typing.overload
    def beginPaint(self, cb: PySide6.QtGui.QRhiCommandBuffer, rt: PySide6.QtGui.QRhiRenderTarget, matrix: PySide6.QtGui.QMatrix4x4 | PySide6.QtGui.QTransform, /, flags: PySide6.QtCanvasPainter.QCanvasRhiPaintDriver.BeginPaintFlag = ...) -> None: ...
    @typing.overload
    def beginPaint(self, cb: PySide6.QtGui.QRhiCommandBuffer, rt: PySide6.QtGui.QRhiRenderTarget, /, fillColor: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int = ..., logicalSize: PySide6.QtCore.QSize = ..., dpr: float = ..., flags: PySide6.QtCanvasPainter.QCanvasRhiPaintDriver.BeginPaintFlag = ...) -> None: ...
    @typing.overload
    def beginPaint(self, canvas: PySide6.QtCanvasPainter.QCanvasOffscreenCanvas, cb: PySide6.QtGui.QRhiCommandBuffer, /, flags: PySide6.QtCanvasPainter.QCanvasRhiPaintDriver.BeginPaintFlag = ...) -> None: ...
    def endPaint(self, /, flags: PySide6.QtCanvasPainter.QCanvasRhiPaintDriver.EndPaintFlag = ...) -> None: ...
    def grabCanvas(self, canvas: PySide6.QtCanvasPainter.QCanvasOffscreenCanvas, resultCallback: collections.abc.Callable[..., typing.Any], /) -> None: ...
    def renderPaint(self, /) -> None: ...
    def resetForNewFrame(self, /) -> None: ...


class QIntList: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.Qt3DExtras, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.Qt3DExtras`

import PySide6.Qt3DExtras
import PySide6.QtCore
import PySide6.QtGui
import PySide6.Qt3DCore
import PySide6.Qt3DRender

import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QIntList: ...


class Qt3DExtras(Shiboken.Object):

    class QAbstractCameraController(PySide6.Qt3DCore.Qt3DCore.QEntity):

        accelerationChanged      : typing.ClassVar[Signal] = ... # accelerationChanged(float)
        cameraChanged            : typing.ClassVar[Signal] = ... # cameraChanged()
        decelerationChanged      : typing.ClassVar[Signal] = ... # decelerationChanged(float)
        linearSpeedChanged       : typing.ClassVar[Signal] = ... # linearSpeedChanged()
        lookSpeedChanged         : typing.ClassVar[Signal] = ... # lookSpeedChanged()

        class InputState(Shiboken.Object):

            altKeyActive              = ...  # type: bool
            leftMouseButtonActive     = ...  # type: bool
            middleMouseButtonActive   = ...  # type: bool
            rightMouseButtonActive    = ...  # type: bool
            rxAxisValue               = ...  # type: float
            ryAxisValue               = ...  # type: float
            shiftKeyActive            = ...  # type: bool
            txAxisValue               = ...  # type: float
            tyAxisValue               = ...  # type: float
            tzAxisValue               = ...  # type: float

            @typing.overload
            def __init__(self, /) -> None: ...
            @typing.overload
            def __init__(self, InputState: PySide6.Qt3DExtras.Qt3DExtras.QAbstractCameraController.InputState, /) -> None: ...

            def __copy__(self, /) -> typing.Self: ...


        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, camera: PySide6.Qt3DRender.Qt3DRender.QCamera | None = ..., linearSpeed: float | None = ..., lookSpeed: float | None = ..., acceleration: float | None = ..., deceleration: float | None = ...) -> None: ...

        def acceleration(self, /) -> float: ...
        def camera(self, /) -> PySide6.Qt3DRender.Qt3DRender.QCamera: ...
        def deceleration(self, /) -> float: ...
        def linearSpeed(self, /) -> float: ...
        def lookSpeed(self, /) -> float: ...
        def setAcceleration(self, acceleration: float, /) -> None: ...
        def setCamera(self, camera: PySide6.Qt3DRender.Qt3DRender.QCamera, /) -> None: ...
        def setDeceleration(self, deceleration: float, /) -> None: ...
        def setLinearSpeed(self, linearSpeed: float, /) -> None: ...
        def setLookSpeed(self, lookSpeed: float, /) -> None: ...

    class QAbstractSpriteSheet(PySide6.Qt3DCore.Qt3DCore.QNode):

        currentIndexChanged      : typing.ClassVar[Signal] = ... # currentIndexChanged(int)
        textureChanged           : typing.ClassVar[Signal] = ... # textureChanged(Qt3DRender::QAbstractTexture*)
        textureTransformChanged  : typing.ClassVar[Signal] = ... # textureTransformChanged(QMatrix3x3)
        def currentIndex(self, /) -> int: ...
        def setCurrentIndex(self, currentIndex: int, /) -> None: ...
        def setTexture(self, texture: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture, /) -> None: ...
        def texture(self, /) -> PySide6.Qt3DRender.Qt3DRender.QAbstractTexture: ...
        def textureTransform(self, /) -> PySide6.QtGui.QMatrix3x3: ...

    class QConeGeometry(PySide6.Qt3DCore.Qt3DCore.QGeometry):

        bottomRadiusChanged      : typing.ClassVar[Signal] = ... # bottomRadiusChanged(float)
        hasBottomEndcapChanged   : typing.ClassVar[Signal] = ... # hasBottomEndcapChanged(bool)
        hasTopEndcapChanged      : typing.ClassVar[Signal] = ... # hasTopEndcapChanged(bool)
        lengthChanged            : typing.ClassVar[Signal] = ... # lengthChanged(float)
        ringsChanged             : typing.ClassVar[Signal] = ... # ringsChanged(int)
        slicesChanged            : typing.ClassVar[Signal] = ... # slicesChanged(int)
        topRadiusChanged         : typing.ClassVar[Signal] = ... # topRadiusChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, hasTopEndcap: bool | None = ..., hasBottomEndcap: bool | None = ..., rings: int | None = ..., slices: int | None = ..., topRadius: float | None = ..., bottomRadius: float | None = ..., length: float | None = ..., positionAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., normalAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., texCoordAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., indexAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ...) -> None: ...

        def bottomRadius(self, /) -> float: ...
        def hasBottomEndcap(self, /) -> bool: ...
        def hasTopEndcap(self, /) -> bool: ...
        def indexAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def length(self, /) -> float: ...
        def normalAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def positionAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def rings(self, /) -> int: ...
        def setBottomRadius(self, bottomRadius: float, /) -> None: ...
        def setHasBottomEndcap(self, hasBottomEndcap: bool, /) -> None: ...
        def setHasTopEndcap(self, hasTopEndcap: bool, /) -> None: ...
        def setLength(self, length: float, /) -> None: ...
        def setRings(self, rings: int, /) -> None: ...
        def setSlices(self, slices: int, /) -> None: ...
        def setTopRadius(self, topRadius: float, /) -> None: ...
        def slices(self, /) -> int: ...
        def texCoordAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def topRadius(self, /) -> float: ...
        def updateIndices(self, /) -> None: ...
        def updateVertices(self, /) -> None: ...

    class QConeGeometryView(PySide6.Qt3DCore.Qt3DCore.QGeometryView):

        bottomRadiusChanged      : typing.ClassVar[Signal] = ... # bottomRadiusChanged(float)
        hasBottomEndcapChanged   : typing.ClassVar[Signal] = ... # hasBottomEndcapChanged(bool)
        hasTopEndcapChanged      : typing.ClassVar[Signal] = ... # hasTopEndcapChanged(bool)
        lengthChanged            : typing.ClassVar[Signal] = ... # lengthChanged(float)
        ringsChanged             : typing.ClassVar[Signal] = ... # ringsChanged(int)
        slicesChanged            : typing.ClassVar[Signal] = ... # slicesChanged(int)
        topRadiusChanged         : typing.ClassVar[Signal] = ... # topRadiusChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, rings: int | None = ..., slices: int | None = ..., hasTopEndcap: bool | None = ..., hasBottomEndcap: bool | None = ..., topRadius: float | None = ..., bottomRadius: float | None = ..., length: float | None = ...) -> None: ...

        def bottomRadius(self, /) -> float: ...
        def hasBottomEndcap(self, /) -> bool: ...
        def hasTopEndcap(self, /) -> bool: ...
        def length(self, /) -> float: ...
        def rings(self, /) -> int: ...
        def setBottomRadius(self, bottomRadius: float, /) -> None: ...
        def setFirstInstance(self, firstInstance: int, /) -> None: ...
        def setGeometry(self, geometry: PySide6.Qt3DCore.Qt3DCore.QGeometry, /) -> None: ...
        def setHasBottomEndcap(self, hasBottomEndcap: bool, /) -> None: ...
        def setHasTopEndcap(self, hasTopEndcap: bool, /) -> None: ...
        def setIndexOffset(self, indexOffset: int, /) -> None: ...
        def setInstanceCount(self, instanceCount: int, /) -> None: ...
        def setLength(self, length: float, /) -> None: ...
        def setPrimitiveRestartEnabled(self, enabled: bool, /) -> None: ...
        def setPrimitiveType(self, primitiveType: PySide6.Qt3DCore.Qt3DCore.QGeometryView.PrimitiveType, /) -> None: ...
        def setRestartIndexValue(self, index: int, /) -> None: ...
        def setRings(self, rings: int, /) -> None: ...
        def setSlices(self, slices: int, /) -> None: ...
        def setTopRadius(self, topRadius: float, /) -> None: ...
        def setVertexCount(self, vertexCount: int, /) -> None: ...
        def slices(self, /) -> int: ...
        def topRadius(self, /) -> float: ...

    class QConeMesh(PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer):

        bottomRadiusChanged      : typing.ClassVar[Signal] = ... # bottomRadiusChanged(float)
        hasBottomEndcapChanged   : typing.ClassVar[Signal] = ... # hasBottomEndcapChanged(bool)
        hasTopEndcapChanged      : typing.ClassVar[Signal] = ... # hasTopEndcapChanged(bool)
        lengthChanged            : typing.ClassVar[Signal] = ... # lengthChanged(float)
        ringsChanged             : typing.ClassVar[Signal] = ... # ringsChanged(int)
        slicesChanged            : typing.ClassVar[Signal] = ... # slicesChanged(int)
        topRadiusChanged         : typing.ClassVar[Signal] = ... # topRadiusChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, rings: int | None = ..., slices: int | None = ..., hasTopEndcap: bool | None = ..., hasBottomEndcap: bool | None = ..., topRadius: float | None = ..., bottomRadius: float | None = ..., length: float | None = ...) -> None: ...

        def bottomRadius(self, /) -> float: ...
        def hasBottomEndcap(self, /) -> bool: ...
        def hasTopEndcap(self, /) -> bool: ...
        def length(self, /) -> float: ...
        def rings(self, /) -> int: ...
        def setBottomRadius(self, bottomRadius: float, /) -> None: ...
        def setFirstInstance(self, firstInstance: int, /) -> None: ...
        def setGeometry(self, geometry: PySide6.Qt3DCore.Qt3DCore.QGeometry, /) -> None: ...
        def setHasBottomEndcap(self, hasBottomEndcap: bool, /) -> None: ...
        def setHasTopEndcap(self, hasTopEndcap: bool, /) -> None: ...
        def setIndexOffset(self, indexOffset: int, /) -> None: ...
        def setInstanceCount(self, instanceCount: int, /) -> None: ...
        def setLength(self, length: float, /) -> None: ...
        def setPrimitiveRestartEnabled(self, enabled: bool, /) -> None: ...
        def setPrimitiveType(self, primitiveType: PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer.PrimitiveType, /) -> None: ...
        def setRestartIndexValue(self, index: int, /) -> None: ...
        def setRings(self, rings: int, /) -> None: ...
        def setSlices(self, slices: int, /) -> None: ...
        def setTopRadius(self, topRadius: float, /) -> None: ...
        def setVertexCount(self, vertexCount: int, /) -> None: ...
        def slices(self, /) -> int: ...
        def topRadius(self, /) -> float: ...

    class QCuboidGeometry(PySide6.Qt3DCore.Qt3DCore.QGeometry):

        xExtentChanged           : typing.ClassVar[Signal] = ... # xExtentChanged(float)
        xyMeshResolutionChanged  : typing.ClassVar[Signal] = ... # xyMeshResolutionChanged(QSize)
        xzMeshResolutionChanged  : typing.ClassVar[Signal] = ... # xzMeshResolutionChanged(QSize)
        yExtentChanged           : typing.ClassVar[Signal] = ... # yExtentChanged(float)
        yzMeshResolutionChanged  : typing.ClassVar[Signal] = ... # yzMeshResolutionChanged(QSize)
        zExtentChanged           : typing.ClassVar[Signal] = ... # zExtentChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, xExtent: float | None = ..., yExtent: float | None = ..., zExtent: float | None = ..., xyMeshResolution: PySide6.QtCore.QSize | None = ..., yzMeshResolution: PySide6.QtCore.QSize | None = ..., xzMeshResolution: PySide6.QtCore.QSize | None = ..., positionAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., normalAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., texCoordAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., tangentAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., indexAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ...) -> None: ...

        def indexAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def normalAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def positionAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def setXExtent(self, xExtent: float, /) -> None: ...
        def setXYMeshResolution(self, resolution: PySide6.QtCore.QSize, /) -> None: ...
        def setXZMeshResolution(self, resolution: PySide6.QtCore.QSize, /) -> None: ...
        def setYExtent(self, yExtent: float, /) -> None: ...
        def setYZMeshResolution(self, resolution: PySide6.QtCore.QSize, /) -> None: ...
        def setZExtent(self, zExtent: float, /) -> None: ...
        def tangentAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def texCoordAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def updateIndices(self, /) -> None: ...
        def updateVertices(self, /) -> None: ...
        def xExtent(self, /) -> float: ...
        def xyMeshResolution(self, /) -> PySide6.QtCore.QSize: ...
        def xzMeshResolution(self, /) -> PySide6.QtCore.QSize: ...
        def yExtent(self, /) -> float: ...
        def yzMeshResolution(self, /) -> PySide6.QtCore.QSize: ...
        def zExtent(self, /) -> float: ...

    class QCuboidGeometryView(PySide6.Qt3DCore.Qt3DCore.QGeometryView):

        xExtentChanged           : typing.ClassVar[Signal] = ... # xExtentChanged(float)
        xyMeshResolutionChanged  : typing.ClassVar[Signal] = ... # xyMeshResolutionChanged(QSize)
        xzMeshResolutionChanged  : typing.ClassVar[Signal] = ... # xzMeshResolutionChanged(QSize)
        yExtentChanged           : typing.ClassVar[Signal] = ... # yExtentChanged(float)
        yzMeshResolutionChanged  : typing.ClassVar[Signal] = ... # yzMeshResolutionChanged(QSize)
        zExtentChanged           : typing.ClassVar[Signal] = ... # zExtentChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, xExtent: float | None = ..., yExtent: float | None = ..., zExtent: float | None = ..., yzMeshResolution: PySide6.QtCore.QSize | None = ..., xzMeshResolution: PySide6.QtCore.QSize | None = ..., xyMeshResolution: PySide6.QtCore.QSize | None = ...) -> None: ...

        def setFirstInstance(self, firstInstance: int, /) -> None: ...
        def setGeometry(self, geometry: PySide6.Qt3DCore.Qt3DCore.QGeometry, /) -> None: ...
        def setIndexOffset(self, indexOffset: int, /) -> None: ...
        def setInstanceCount(self, instanceCount: int, /) -> None: ...
        def setPrimitiveRestartEnabled(self, enabled: bool, /) -> None: ...
        def setPrimitiveType(self, primitiveType: PySide6.Qt3DCore.Qt3DCore.QGeometryView.PrimitiveType, /) -> None: ...
        def setRestartIndexValue(self, index: int, /) -> None: ...
        def setVertexCount(self, vertexCount: int, /) -> None: ...
        def setXExtent(self, xExtent: float, /) -> None: ...
        def setXYMeshResolution(self, resolution: PySide6.QtCore.QSize, /) -> None: ...
        def setXZMeshResolution(self, resolution: PySide6.QtCore.QSize, /) -> None: ...
        def setYExtent(self, yExtent: float, /) -> None: ...
        def setYZMeshResolution(self, resolution: PySide6.QtCore.QSize, /) -> None: ...
        def setZExtent(self, zExtent: float, /) -> None: ...
        def xExtent(self, /) -> float: ...
        def xyMeshResolution(self, /) -> PySide6.QtCore.QSize: ...
        def xzMeshResolution(self, /) -> PySide6.QtCore.QSize: ...
        def yExtent(self, /) -> float: ...
        def yzMeshResolution(self, /) -> PySide6.QtCore.QSize: ...
        def zExtent(self, /) -> float: ...

    class QCuboidMesh(PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer):

        xExtentChanged           : typing.ClassVar[Signal] = ... # xExtentChanged(float)
        xyMeshResolutionChanged  : typing.ClassVar[Signal] = ... # xyMeshResolutionChanged(QSize)
        xzMeshResolutionChanged  : typing.ClassVar[Signal] = ... # xzMeshResolutionChanged(QSize)
        yExtentChanged           : typing.ClassVar[Signal] = ... # yExtentChanged(float)
        yzMeshResolutionChanged  : typing.ClassVar[Signal] = ... # yzMeshResolutionChanged(QSize)
        zExtentChanged           : typing.ClassVar[Signal] = ... # zExtentChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, xExtent: float | None = ..., yExtent: float | None = ..., zExtent: float | None = ..., yzMeshResolution: PySide6.QtCore.QSize | None = ..., xzMeshResolution: PySide6.QtCore.QSize | None = ..., xyMeshResolution: PySide6.QtCore.QSize | None = ...) -> None: ...

        def setFirstInstance(self, firstInstance: int, /) -> None: ...
        def setGeometry(self, geometry: PySide6.Qt3DCore.Qt3DCore.QGeometry, /) -> None: ...
        def setIndexOffset(self, indexOffset: int, /) -> None: ...
        def setInstanceCount(self, instanceCount: int, /) -> None: ...
        def setPrimitiveRestartEnabled(self, enabled: bool, /) -> None: ...
        def setPrimitiveType(self, primitiveType: PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer.PrimitiveType, /) -> None: ...
        def setRestartIndexValue(self, index: int, /) -> None: ...
        def setVertexCount(self, vertexCount: int, /) -> None: ...
        def setXExtent(self, xExtent: float, /) -> None: ...
        def setXYMeshResolution(self, resolution: PySide6.QtCore.QSize, /) -> None: ...
        def setXZMeshResolution(self, resolution: PySide6.QtCore.QSize, /) -> None: ...
        def setYExtent(self, yExtent: float, /) -> None: ...
        def setYZMeshResolution(self, resolution: PySide6.QtCore.QSize, /) -> None: ...
        def setZExtent(self, zExtent: float, /) -> None: ...
        def xExtent(self, /) -> float: ...
        def xyMeshResolution(self, /) -> PySide6.QtCore.QSize: ...
        def xzMeshResolution(self, /) -> PySide6.QtCore.QSize: ...
        def yExtent(self, /) -> float: ...
        def yzMeshResolution(self, /) -> PySide6.QtCore.QSize: ...
        def zExtent(self, /) -> float: ...

    class QCylinderGeometry(PySide6.Qt3DCore.Qt3DCore.QGeometry):

        lengthChanged            : typing.ClassVar[Signal] = ... # lengthChanged(float)
        radiusChanged            : typing.ClassVar[Signal] = ... # radiusChanged(float)
        ringsChanged             : typing.ClassVar[Signal] = ... # ringsChanged(int)
        slicesChanged            : typing.ClassVar[Signal] = ... # slicesChanged(int)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, rings: int | None = ..., slices: int | None = ..., radius: float | None = ..., length: float | None = ..., positionAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., normalAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., texCoordAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., indexAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ...) -> None: ...

        def indexAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def length(self, /) -> float: ...
        def normalAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def positionAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def radius(self, /) -> float: ...
        def rings(self, /) -> int: ...
        def setLength(self, length: float, /) -> None: ...
        def setRadius(self, radius: float, /) -> None: ...
        def setRings(self, rings: int, /) -> None: ...
        def setSlices(self, slices: int, /) -> None: ...
        def slices(self, /) -> int: ...
        def texCoordAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def updateIndices(self, /) -> None: ...
        def updateVertices(self, /) -> None: ...

    class QCylinderGeometryView(PySide6.Qt3DCore.Qt3DCore.QGeometryView):

        lengthChanged            : typing.ClassVar[Signal] = ... # lengthChanged(float)
        radiusChanged            : typing.ClassVar[Signal] = ... # radiusChanged(float)
        ringsChanged             : typing.ClassVar[Signal] = ... # ringsChanged(int)
        slicesChanged            : typing.ClassVar[Signal] = ... # slicesChanged(int)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, rings: int | None = ..., slices: int | None = ..., radius: float | None = ..., length: float | None = ...) -> None: ...

        def length(self, /) -> float: ...
        def radius(self, /) -> float: ...
        def rings(self, /) -> int: ...
        def setFirstInstance(self, firstInstance: int, /) -> None: ...
        def setGeometry(self, geometry: PySide6.Qt3DCore.Qt3DCore.QGeometry, /) -> None: ...
        def setIndexOffset(self, indexOffset: int, /) -> None: ...
        def setInstanceCount(self, instanceCount: int, /) -> None: ...
        def setLength(self, length: float, /) -> None: ...
        def setPrimitiveRestartEnabled(self, enabled: bool, /) -> None: ...
        def setPrimitiveType(self, primitiveType: PySide6.Qt3DCore.Qt3DCore.QGeometryView.PrimitiveType, /) -> None: ...
        def setRadius(self, radius: float, /) -> None: ...
        def setRestartIndexValue(self, index: int, /) -> None: ...
        def setRings(self, rings: int, /) -> None: ...
        def setSlices(self, slices: int, /) -> None: ...
        def setVertexCount(self, vertexCount: int, /) -> None: ...
        def slices(self, /) -> int: ...

    class QCylinderMesh(PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer):

        lengthChanged            : typing.ClassVar[Signal] = ... # lengthChanged(float)
        radiusChanged            : typing.ClassVar[Signal] = ... # radiusChanged(float)
        ringsChanged             : typing.ClassVar[Signal] = ... # ringsChanged(int)
        slicesChanged            : typing.ClassVar[Signal] = ... # slicesChanged(int)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, rings: int | None = ..., slices: int | None = ..., radius: float | None = ..., length: float | None = ...) -> None: ...

        def length(self, /) -> float: ...
        def radius(self, /) -> float: ...
        def rings(self, /) -> int: ...
        def setFirstInstance(self, firstInstance: int, /) -> None: ...
        def setGeometry(self, geometry: PySide6.Qt3DCore.Qt3DCore.QGeometry, /) -> None: ...
        def setIndexOffset(self, indexOffset: int, /) -> None: ...
        def setInstanceCount(self, instanceCount: int, /) -> None: ...
        def setLength(self, length: float, /) -> None: ...
        def setPrimitiveRestartEnabled(self, enabled: bool, /) -> None: ...
        def setPrimitiveType(self, primitiveType: PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer.PrimitiveType, /) -> None: ...
        def setRadius(self, radius: float, /) -> None: ...
        def setRestartIndexValue(self, index: int, /) -> None: ...
        def setRings(self, rings: int, /) -> None: ...
        def setSlices(self, slices: int, /) -> None: ...
        def setVertexCount(self, vertexCount: int, /) -> None: ...
        def slices(self, /) -> int: ...

    class QDiffuseMapMaterial(PySide6.Qt3DRender.Qt3DRender.QMaterial):

        ambientChanged           : typing.ClassVar[Signal] = ... # ambientChanged(QColor)
        diffuseChanged           : typing.ClassVar[Signal] = ... # diffuseChanged(Qt3DRender::QAbstractTexture*)
        shininessChanged         : typing.ClassVar[Signal] = ... # shininessChanged(float)
        specularChanged          : typing.ClassVar[Signal] = ... # specularChanged(QColor)
        textureScaleChanged      : typing.ClassVar[Signal] = ... # textureScaleChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, ambient: PySide6.QtGui.QColor | None = ..., specular: PySide6.QtGui.QColor | None = ..., shininess: float | None = ..., diffuse: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture | None = ..., textureScale: float | None = ...) -> None: ...

        def ambient(self, /) -> PySide6.QtGui.QColor: ...
        def diffuse(self, /) -> PySide6.Qt3DRender.Qt3DRender.QAbstractTexture: ...
        def setAmbient(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setDiffuse(self, diffuse: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture, /) -> None: ...
        def setShininess(self, shininess: float, /) -> None: ...
        def setSpecular(self, specular: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setTextureScale(self, textureScale: float, /) -> None: ...
        def shininess(self, /) -> float: ...
        def specular(self, /) -> PySide6.QtGui.QColor: ...
        def textureScale(self, /) -> float: ...

    class QDiffuseSpecularMapMaterial(PySide6.Qt3DRender.Qt3DRender.QMaterial):

        ambientChanged           : typing.ClassVar[Signal] = ... # ambientChanged(QColor)
        diffuseChanged           : typing.ClassVar[Signal] = ... # diffuseChanged(Qt3DRender::QAbstractTexture*)
        shininessChanged         : typing.ClassVar[Signal] = ... # shininessChanged(float)
        specularChanged          : typing.ClassVar[Signal] = ... # specularChanged(Qt3DRender::QAbstractTexture*)
        textureScaleChanged      : typing.ClassVar[Signal] = ... # textureScaleChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, ambient: PySide6.QtGui.QColor | None = ..., shininess: float | None = ..., specular: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture | None = ..., diffuse: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture | None = ..., textureScale: float | None = ...) -> None: ...

        def ambient(self, /) -> PySide6.QtGui.QColor: ...
        def diffuse(self, /) -> PySide6.Qt3DRender.Qt3DRender.QAbstractTexture: ...
        def setAmbient(self, ambient: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setDiffuse(self, diffuse: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture, /) -> None: ...
        def setShininess(self, shininess: float, /) -> None: ...
        def setSpecular(self, specular: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture, /) -> None: ...
        def setTextureScale(self, textureScale: float, /) -> None: ...
        def shininess(self, /) -> float: ...
        def specular(self, /) -> PySide6.Qt3DRender.Qt3DRender.QAbstractTexture: ...
        def textureScale(self, /) -> float: ...

    class QDiffuseSpecularMaterial(PySide6.Qt3DRender.Qt3DRender.QMaterial):

        alphaBlendingEnabledChanged: typing.ClassVar[Signal] = ... # alphaBlendingEnabledChanged(bool)
        ambientChanged           : typing.ClassVar[Signal] = ... # ambientChanged(QColor)
        diffuseChanged           : typing.ClassVar[Signal] = ... # diffuseChanged(QVariant)
        normalChanged            : typing.ClassVar[Signal] = ... # normalChanged(QVariant)
        shininessChanged         : typing.ClassVar[Signal] = ... # shininessChanged(float)
        specularChanged          : typing.ClassVar[Signal] = ... # specularChanged(QVariant)
        textureScaleChanged      : typing.ClassVar[Signal] = ... # textureScaleChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, ambient: PySide6.QtGui.QColor | None = ..., diffuse: typing.Any | None = ..., specular: typing.Any | None = ..., shininess: float | None = ..., normal: typing.Any | None = ..., textureScale: float | None = ..., alphaBlending: bool | None = ...) -> None: ...

        def ambient(self, /) -> PySide6.QtGui.QColor: ...
        def diffuse(self, /) -> typing.Any: ...
        def isAlphaBlendingEnabled(self, /) -> bool: ...
        def normal(self, /) -> typing.Any: ...
        def setAlphaBlendingEnabled(self, enabled: bool, /) -> None: ...
        def setAmbient(self, ambient: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setDiffuse(self, diffuse: typing.Any, /) -> None: ...
        def setNormal(self, normal: typing.Any, /) -> None: ...
        def setShininess(self, shininess: float, /) -> None: ...
        def setSpecular(self, specular: typing.Any, /) -> None: ...
        def setTextureScale(self, textureScale: float, /) -> None: ...
        def shininess(self, /) -> float: ...
        def specular(self, /) -> typing.Any: ...
        def textureScale(self, /) -> float: ...

    class QExtrudedTextGeometry(PySide6.Qt3DCore.Qt3DCore.QGeometry):

        depthChanged             : typing.ClassVar[Signal] = ... # depthChanged(float)
        fontChanged              : typing.ClassVar[Signal] = ... # fontChanged(QFont)
        textChanged              : typing.ClassVar[Signal] = ... # textChanged(QString)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, text: str | None = ..., font: PySide6.QtGui.QFont | None = ..., extrusionLength: float | None = ..., positionAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., normalAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., indexAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ...) -> None: ...

        def extrusionLength(self, /) -> float: ...
        def font(self, /) -> PySide6.QtGui.QFont: ...
        def indexAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def normalAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def positionAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def setDepth(self, extrusionLength: float, /) -> None: ...
        def setFont(self, font: PySide6.QtGui.QFont | str | collections.abc.Sequence[str], /) -> None: ...
        def setText(self, text: str, /) -> None: ...
        def text(self, /) -> str: ...

    class QExtrudedTextMesh(PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer):

        depthChanged             : typing.ClassVar[Signal] = ... # depthChanged(float)
        fontChanged              : typing.ClassVar[Signal] = ... # fontChanged(QFont)
        textChanged              : typing.ClassVar[Signal] = ... # textChanged(QString)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, text: str | None = ..., font: PySide6.QtGui.QFont | None = ..., depth: float | None = ...) -> None: ...

        def depth(self, /) -> float: ...
        def font(self, /) -> PySide6.QtGui.QFont: ...
        def setDepth(self, depth: float, /) -> None: ...
        def setFont(self, font: PySide6.QtGui.QFont | str | collections.abc.Sequence[str], /) -> None: ...
        def setText(self, text: str, /) -> None: ...
        def text(self, /) -> str: ...

    class QFirstPersonCameraController(PySide6.Qt3DExtras.Qt3DExtras.QAbstractCameraController):

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ...) -> None: ...


    class QForwardRenderer(PySide6.Qt3DRender.Qt3DRender.QTechniqueFilter):

        buffersToClearChanged    : typing.ClassVar[Signal] = ... # buffersToClearChanged(Qt3DRender::QClearBuffers::BufferType)
        cameraChanged            : typing.ClassVar[Signal] = ... # cameraChanged(Qt3DCore::QEntity*)
        clearColorChanged        : typing.ClassVar[Signal] = ... # clearColorChanged(QColor)
        externalRenderTargetSizeChanged: typing.ClassVar[Signal] = ... # externalRenderTargetSizeChanged(QSize)
        frustumCullingEnabledChanged: typing.ClassVar[Signal] = ... # frustumCullingEnabledChanged(bool)
        gammaChanged             : typing.ClassVar[Signal] = ... # gammaChanged(float)
        showDebugOverlayChanged  : typing.ClassVar[Signal] = ... # showDebugOverlayChanged(bool)
        surfaceChanged           : typing.ClassVar[Signal] = ... # surfaceChanged(QObject*)
        viewportRectChanged      : typing.ClassVar[Signal] = ... # viewportRectChanged(QRectF)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, surface: PySide6.QtCore.QObject | None = ..., window: PySide6.QtCore.QObject | None = ..., viewportRect: PySide6.QtCore.QRectF | None = ..., clearColor: PySide6.QtGui.QColor | None = ..., buffersToClear: PySide6.Qt3DRender.Qt3DRender.QClearBuffers.BufferType | None = ..., camera: PySide6.Qt3DCore.Qt3DCore.QEntity | None = ..., externalRenderTargetSize: PySide6.QtCore.QSize | None = ..., frustumCulling: bool | None = ..., gamma: float | None = ..., showDebugOverlay: bool | None = ...) -> None: ...

        def buffersToClear(self, /) -> PySide6.Qt3DRender.Qt3DRender.QClearBuffers.BufferType: ...
        def camera(self, /) -> PySide6.Qt3DCore.Qt3DCore.QEntity: ...
        def clearColor(self, /) -> PySide6.QtGui.QColor: ...
        def externalRenderTargetSize(self, /) -> PySide6.QtCore.QSize: ...
        def gamma(self, /) -> float: ...
        def isFrustumCullingEnabled(self, /) -> bool: ...
        def setBuffersToClear(self, arg__1: PySide6.Qt3DRender.Qt3DRender.QClearBuffers.BufferType, /) -> None: ...
        def setCamera(self, camera: PySide6.Qt3DCore.Qt3DCore.QEntity, /) -> None: ...
        def setClearColor(self, clearColor: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setExternalRenderTargetSize(self, size: PySide6.QtCore.QSize, /) -> None: ...
        def setFrustumCullingEnabled(self, enabled: bool, /) -> None: ...
        def setGamma(self, gamma: float, /) -> None: ...
        def setShowDebugOverlay(self, showDebugOverlay: bool, /) -> None: ...
        def setSurface(self, surface: PySide6.QtCore.QObject, /) -> None: ...
        def setViewportRect(self, viewportRect: PySide6.QtCore.QRectF | PySide6.QtCore.QRect, /) -> None: ...
        def showDebugOverlay(self, /) -> bool: ...
        def surface(self, /) -> PySide6.QtCore.QObject: ...
        def viewportRect(self, /) -> PySide6.QtCore.QRectF: ...

    class QGoochMaterial(PySide6.Qt3DRender.Qt3DRender.QMaterial):

        alphaChanged             : typing.ClassVar[Signal] = ... # alphaChanged(float)
        betaChanged              : typing.ClassVar[Signal] = ... # betaChanged(float)
        coolChanged              : typing.ClassVar[Signal] = ... # coolChanged(QColor)
        diffuseChanged           : typing.ClassVar[Signal] = ... # diffuseChanged(QColor)
        shininessChanged         : typing.ClassVar[Signal] = ... # shininessChanged(float)
        specularChanged          : typing.ClassVar[Signal] = ... # specularChanged(QColor)
        warmChanged              : typing.ClassVar[Signal] = ... # warmChanged(QColor)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, diffuse: PySide6.QtGui.QColor | None = ..., specular: PySide6.QtGui.QColor | None = ..., cool: PySide6.QtGui.QColor | None = ..., warm: PySide6.QtGui.QColor | None = ..., alpha: float | None = ..., beta: float | None = ..., shininess: float | None = ...) -> None: ...

        def alpha(self, /) -> float: ...
        def beta(self, /) -> float: ...
        def cool(self, /) -> PySide6.QtGui.QColor: ...
        def diffuse(self, /) -> PySide6.QtGui.QColor: ...
        def setAlpha(self, alpha: float, /) -> None: ...
        def setBeta(self, beta: float, /) -> None: ...
        def setCool(self, cool: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setDiffuse(self, diffuse: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setShininess(self, shininess: float, /) -> None: ...
        def setSpecular(self, specular: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setWarm(self, warm: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def shininess(self, /) -> float: ...
        def specular(self, /) -> PySide6.QtGui.QColor: ...
        def warm(self, /) -> PySide6.QtGui.QColor: ...

    class QMetalRoughMaterial(PySide6.Qt3DRender.Qt3DRender.QMaterial):

        ambientOcclusionChanged  : typing.ClassVar[Signal] = ... # ambientOcclusionChanged(QVariant)
        baseColorChanged         : typing.ClassVar[Signal] = ... # baseColorChanged(QVariant)
        metalnessChanged         : typing.ClassVar[Signal] = ... # metalnessChanged(QVariant)
        normalChanged            : typing.ClassVar[Signal] = ... # normalChanged(QVariant)
        roughnessChanged         : typing.ClassVar[Signal] = ... # roughnessChanged(QVariant)
        textureScaleChanged      : typing.ClassVar[Signal] = ... # textureScaleChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, baseColor: typing.Any | None = ..., metalness: typing.Any | None = ..., roughness: typing.Any | None = ..., ambientOcclusion: typing.Any | None = ..., normal: typing.Any | None = ..., textureScale: float | None = ...) -> None: ...

        def ambientOcclusion(self, /) -> typing.Any: ...
        def baseColor(self, /) -> typing.Any: ...
        def metalness(self, /) -> typing.Any: ...
        def normal(self, /) -> typing.Any: ...
        def roughness(self, /) -> typing.Any: ...
        def setAmbientOcclusion(self, ambientOcclusion: typing.Any, /) -> None: ...
        def setBaseColor(self, baseColor: typing.Any, /) -> None: ...
        def setMetalness(self, metalness: typing.Any, /) -> None: ...
        def setNormal(self, normal: typing.Any, /) -> None: ...
        def setRoughness(self, roughness: typing.Any, /) -> None: ...
        def setTextureScale(self, textureScale: float, /) -> None: ...
        def textureScale(self, /) -> float: ...

    class QMorphPhongMaterial(PySide6.Qt3DRender.Qt3DRender.QMaterial):

        ambientChanged           : typing.ClassVar[Signal] = ... # ambientChanged(QColor)
        diffuseChanged           : typing.ClassVar[Signal] = ... # diffuseChanged(QColor)
        interpolatorChanged      : typing.ClassVar[Signal] = ... # interpolatorChanged(float)
        shininessChanged         : typing.ClassVar[Signal] = ... # shininessChanged(float)
        specularChanged          : typing.ClassVar[Signal] = ... # specularChanged(QColor)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, ambient: PySide6.QtGui.QColor | None = ..., diffuse: PySide6.QtGui.QColor | None = ..., specular: PySide6.QtGui.QColor | None = ..., shininess: float | None = ..., interpolator: float | None = ...) -> None: ...

        def ambient(self, /) -> PySide6.QtGui.QColor: ...
        def diffuse(self, /) -> PySide6.QtGui.QColor: ...
        def interpolator(self, /) -> float: ...
        def setAmbient(self, ambient: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setDiffuse(self, diffuse: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setInterpolator(self, interpolator: float, /) -> None: ...
        def setShininess(self, shininess: float, /) -> None: ...
        def setSpecular(self, specular: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def shininess(self, /) -> float: ...
        def specular(self, /) -> PySide6.QtGui.QColor: ...

    class QNormalDiffuseMapAlphaMaterial(PySide6.Qt3DExtras.Qt3DExtras.QNormalDiffuseMapMaterial):

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ...) -> None: ...


    class QNormalDiffuseMapMaterial(PySide6.Qt3DRender.Qt3DRender.QMaterial):

        ambientChanged           : typing.ClassVar[Signal] = ... # ambientChanged(QColor)
        diffuseChanged           : typing.ClassVar[Signal] = ... # diffuseChanged(Qt3DRender::QAbstractTexture*)
        normalChanged            : typing.ClassVar[Signal] = ... # normalChanged(Qt3DRender::QAbstractTexture*)
        shininessChanged         : typing.ClassVar[Signal] = ... # shininessChanged(float)
        specularChanged          : typing.ClassVar[Signal] = ... # specularChanged(QColor)
        textureScaleChanged      : typing.ClassVar[Signal] = ... # textureScaleChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, ambient: PySide6.QtGui.QColor | None = ..., specular: PySide6.QtGui.QColor | None = ..., diffuse: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture | None = ..., normal: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture | None = ..., shininess: float | None = ..., textureScale: float | None = ...) -> None: ...

        def ambient(self, /) -> PySide6.QtGui.QColor: ...
        def diffuse(self, /) -> PySide6.Qt3DRender.Qt3DRender.QAbstractTexture: ...
        def normal(self, /) -> PySide6.Qt3DRender.Qt3DRender.QAbstractTexture: ...
        def setAmbient(self, ambient: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setDiffuse(self, diffuse: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture, /) -> None: ...
        def setNormal(self, normal: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture, /) -> None: ...
        def setShininess(self, shininess: float, /) -> None: ...
        def setSpecular(self, specular: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setTextureScale(self, textureScale: float, /) -> None: ...
        def shininess(self, /) -> float: ...
        def specular(self, /) -> PySide6.QtGui.QColor: ...
        def textureScale(self, /) -> float: ...

    class QNormalDiffuseSpecularMapMaterial(PySide6.Qt3DRender.Qt3DRender.QMaterial):

        ambientChanged           : typing.ClassVar[Signal] = ... # ambientChanged(QColor)
        diffuseChanged           : typing.ClassVar[Signal] = ... # diffuseChanged(Qt3DRender::QAbstractTexture*)
        normalChanged            : typing.ClassVar[Signal] = ... # normalChanged(Qt3DRender::QAbstractTexture*)
        shininessChanged         : typing.ClassVar[Signal] = ... # shininessChanged(float)
        specularChanged          : typing.ClassVar[Signal] = ... # specularChanged(Qt3DRender::QAbstractTexture*)
        textureScaleChanged      : typing.ClassVar[Signal] = ... # textureScaleChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, ambient: PySide6.QtGui.QColor | None = ..., diffuse: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture | None = ..., normal: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture | None = ..., specular: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture | None = ..., shininess: float | None = ..., textureScale: float | None = ...) -> None: ...

        def ambient(self, /) -> PySide6.QtGui.QColor: ...
        def diffuse(self, /) -> PySide6.Qt3DRender.Qt3DRender.QAbstractTexture: ...
        def normal(self, /) -> PySide6.Qt3DRender.Qt3DRender.QAbstractTexture: ...
        def setAmbient(self, ambient: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setDiffuse(self, diffuse: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture, /) -> None: ...
        def setNormal(self, normal: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture, /) -> None: ...
        def setShininess(self, shininess: float, /) -> None: ...
        def setSpecular(self, specular: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture, /) -> None: ...
        def setTextureScale(self, textureScale: float, /) -> None: ...
        def shininess(self, /) -> float: ...
        def specular(self, /) -> PySide6.Qt3DRender.Qt3DRender.QAbstractTexture: ...
        def textureScale(self, /) -> float: ...

    class QOrbitCameraController(PySide6.Qt3DExtras.Qt3DExtras.QAbstractCameraController):

        inversePanChanged        : typing.ClassVar[Signal] = ... # inversePanChanged(bool)
        inverseTiltChanged       : typing.ClassVar[Signal] = ... # inverseTiltChanged(bool)
        inverseXTranslateChanged : typing.ClassVar[Signal] = ... # inverseXTranslateChanged(bool)
        inverseYTranslateChanged : typing.ClassVar[Signal] = ... # inverseYTranslateChanged(bool)
        upVectorChanged          : typing.ClassVar[Signal] = ... # upVectorChanged(QVector3D)
        zoomInLimitChanged       : typing.ClassVar[Signal] = ... # zoomInLimitChanged()
        zoomTranslateViewCenterChanged: typing.ClassVar[Signal] = ... # zoomTranslateViewCenterChanged(bool)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, zoomInLimit: float | None = ..., upVector: PySide6.QtGui.QVector3D | None = ..., inverseXTranslate: bool | None = ..., inverseYTranslate: bool | None = ..., inversePan: bool | None = ..., inverseTilt: bool | None = ..., zoomTranslateViewCenter: bool | None = ...) -> None: ...

        def inversePan(self, /) -> bool: ...
        def inverseTilt(self, /) -> bool: ...
        def inverseXTranslate(self, /) -> bool: ...
        def inverseYTranslate(self, /) -> bool: ...
        def setInversePan(self, isInverse: bool, /) -> None: ...
        def setInverseTilt(self, isInverse: bool, /) -> None: ...
        def setInverseXTranslate(self, isInverse: bool, /) -> None: ...
        def setInverseYTranslate(self, isInverse: bool, /) -> None: ...
        def setUpVector(self, upVector: PySide6.QtGui.QVector3D, /) -> None: ...
        def setZoomInLimit(self, zoomInLimit: float, /) -> None: ...
        def setZoomTranslateViewCenter(self, isTranslate: bool, /) -> None: ...
        def upVector(self, /) -> PySide6.QtGui.QVector3D: ...
        def zoomInLimit(self, /) -> float: ...
        def zoomTranslateViewCenter(self, /) -> bool: ...

    class QPerVertexColorMaterial(PySide6.Qt3DRender.Qt3DRender.QMaterial):

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ...) -> None: ...


    class QPhongAlphaMaterial(PySide6.Qt3DRender.Qt3DRender.QMaterial):

        alphaChanged             : typing.ClassVar[Signal] = ... # alphaChanged(float)
        ambientChanged           : typing.ClassVar[Signal] = ... # ambientChanged(QColor)
        blendFunctionArgChanged  : typing.ClassVar[Signal] = ... # blendFunctionArgChanged(Qt3DRender::QBlendEquation::BlendFunction)
        destinationAlphaArgChanged: typing.ClassVar[Signal] = ... # destinationAlphaArgChanged(Qt3DRender::QBlendEquationArguments::Blending)
        destinationRgbArgChanged : typing.ClassVar[Signal] = ... # destinationRgbArgChanged(Qt3DRender::QBlendEquationArguments::Blending)
        diffuseChanged           : typing.ClassVar[Signal] = ... # diffuseChanged(QColor)
        shininessChanged         : typing.ClassVar[Signal] = ... # shininessChanged(float)
        sourceAlphaArgChanged    : typing.ClassVar[Signal] = ... # sourceAlphaArgChanged(Qt3DRender::QBlendEquationArguments::Blending)
        sourceRgbArgChanged      : typing.ClassVar[Signal] = ... # sourceRgbArgChanged(Qt3DRender::QBlendEquationArguments::Blending)
        specularChanged          : typing.ClassVar[Signal] = ... # specularChanged(QColor)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, ambient: PySide6.QtGui.QColor | None = ..., diffuse: PySide6.QtGui.QColor | None = ..., specular: PySide6.QtGui.QColor | None = ..., shininess: float | None = ..., alpha: float | None = ..., sourceRgbArg: PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending | None = ..., destinationRgbArg: PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending | None = ..., sourceAlphaArg: PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending | None = ..., destinationAlphaArg: PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending | None = ..., blendFunctionArg: PySide6.Qt3DRender.Qt3DRender.QBlendEquation.BlendFunction | None = ...) -> None: ...

        def alpha(self, /) -> float: ...
        def ambient(self, /) -> PySide6.QtGui.QColor: ...
        def blendFunctionArg(self, /) -> PySide6.Qt3DRender.Qt3DRender.QBlendEquation.BlendFunction: ...
        def destinationAlphaArg(self, /) -> PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending: ...
        def destinationRgbArg(self, /) -> PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending: ...
        def diffuse(self, /) -> PySide6.QtGui.QColor: ...
        def setAlpha(self, alpha: float, /) -> None: ...
        def setAmbient(self, ambient: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setBlendFunctionArg(self, blendFunctionArg: PySide6.Qt3DRender.Qt3DRender.QBlendEquation.BlendFunction, /) -> None: ...
        def setDestinationAlphaArg(self, destinationAlphaArg: PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending, /) -> None: ...
        def setDestinationRgbArg(self, destinationRgbArg: PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending, /) -> None: ...
        def setDiffuse(self, diffuse: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setShininess(self, shininess: float, /) -> None: ...
        def setSourceAlphaArg(self, sourceAlphaArg: PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending, /) -> None: ...
        def setSourceRgbArg(self, sourceRgbArg: PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending, /) -> None: ...
        def setSpecular(self, specular: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def shininess(self, /) -> float: ...
        def sourceAlphaArg(self, /) -> PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending: ...
        def sourceRgbArg(self, /) -> PySide6.Qt3DRender.Qt3DRender.QBlendEquationArguments.Blending: ...
        def specular(self, /) -> PySide6.QtGui.QColor: ...

    class QPhongMaterial(PySide6.Qt3DRender.Qt3DRender.QMaterial):

        ambientChanged           : typing.ClassVar[Signal] = ... # ambientChanged(QColor)
        diffuseChanged           : typing.ClassVar[Signal] = ... # diffuseChanged(QColor)
        shininessChanged         : typing.ClassVar[Signal] = ... # shininessChanged(float)
        specularChanged          : typing.ClassVar[Signal] = ... # specularChanged(QColor)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, ambient: PySide6.QtGui.QColor | None = ..., diffuse: PySide6.QtGui.QColor | None = ..., specular: PySide6.QtGui.QColor | None = ..., shininess: float | None = ...) -> None: ...

        def ambient(self, /) -> PySide6.QtGui.QColor: ...
        def diffuse(self, /) -> PySide6.QtGui.QColor: ...
        def setAmbient(self, ambient: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setDiffuse(self, diffuse: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setShininess(self, shininess: float, /) -> None: ...
        def setSpecular(self, specular: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def shininess(self, /) -> float: ...
        def specular(self, /) -> PySide6.QtGui.QColor: ...

    class QPlaneGeometry(PySide6.Qt3DCore.Qt3DCore.QGeometry):

        heightChanged            : typing.ClassVar[Signal] = ... # heightChanged(float)
        mirroredChanged          : typing.ClassVar[Signal] = ... # mirroredChanged(bool)
        resolutionChanged        : typing.ClassVar[Signal] = ... # resolutionChanged(QSize)
        widthChanged             : typing.ClassVar[Signal] = ... # widthChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, width: float | None = ..., height: float | None = ..., resolution: PySide6.QtCore.QSize | None = ..., mirrored: bool | None = ..., positionAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., normalAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., texCoordAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., tangentAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., indexAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ...) -> None: ...

        def height(self, /) -> float: ...
        def indexAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def mirrored(self, /) -> bool: ...
        def normalAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def positionAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def resolution(self, /) -> PySide6.QtCore.QSize: ...
        def setHeight(self, height: float, /) -> None: ...
        def setMirrored(self, mirrored: bool, /) -> None: ...
        def setResolution(self, resolution: PySide6.QtCore.QSize, /) -> None: ...
        def setWidth(self, width: float, /) -> None: ...
        def tangentAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def texCoordAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def updateIndices(self, /) -> None: ...
        def updateVertices(self, /) -> None: ...
        def width(self, /) -> float: ...

    class QPlaneGeometryView(PySide6.Qt3DCore.Qt3DCore.QGeometryView):

        heightChanged            : typing.ClassVar[Signal] = ... # heightChanged(float)
        meshResolutionChanged    : typing.ClassVar[Signal] = ... # meshResolutionChanged(QSize)
        mirroredChanged          : typing.ClassVar[Signal] = ... # mirroredChanged(bool)
        widthChanged             : typing.ClassVar[Signal] = ... # widthChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, width: float | None = ..., height: float | None = ..., meshResolution: PySide6.QtCore.QSize | None = ..., mirrored: bool | None = ...) -> None: ...

        def height(self, /) -> float: ...
        def meshResolution(self, /) -> PySide6.QtCore.QSize: ...
        def mirrored(self, /) -> bool: ...
        def setFirstInstance(self, firstInstance: int, /) -> None: ...
        def setGeometry(self, geometry: PySide6.Qt3DCore.Qt3DCore.QGeometry, /) -> None: ...
        def setHeight(self, height: float, /) -> None: ...
        def setIndexOffset(self, indexOffset: int, /) -> None: ...
        def setInstanceCount(self, instanceCount: int, /) -> None: ...
        def setMeshResolution(self, resolution: PySide6.QtCore.QSize, /) -> None: ...
        def setMirrored(self, mirrored: bool, /) -> None: ...
        def setPrimitiveRestartEnabled(self, enabled: bool, /) -> None: ...
        def setPrimitiveType(self, primitiveType: PySide6.Qt3DCore.Qt3DCore.QGeometryView.PrimitiveType, /) -> None: ...
        def setRestartIndexValue(self, index: int, /) -> None: ...
        def setVertexCount(self, vertexCount: int, /) -> None: ...
        def setWidth(self, width: float, /) -> None: ...
        def width(self, /) -> float: ...

    class QPlaneMesh(PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer):

        heightChanged            : typing.ClassVar[Signal] = ... # heightChanged(float)
        meshResolutionChanged    : typing.ClassVar[Signal] = ... # meshResolutionChanged(QSize)
        mirroredChanged          : typing.ClassVar[Signal] = ... # mirroredChanged(bool)
        widthChanged             : typing.ClassVar[Signal] = ... # widthChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, width: float | None = ..., height: float | None = ..., meshResolution: PySide6.QtCore.QSize | None = ..., mirrored: bool | None = ...) -> None: ...

        def height(self, /) -> float: ...
        def meshResolution(self, /) -> PySide6.QtCore.QSize: ...
        def mirrored(self, /) -> bool: ...
        def setFirstInstance(self, firstInstance: int, /) -> None: ...
        def setGeometry(self, geometry: PySide6.Qt3DCore.Qt3DCore.QGeometry, /) -> None: ...
        def setHeight(self, height: float, /) -> None: ...
        def setIndexOffset(self, indexOffset: int, /) -> None: ...
        def setInstanceCount(self, instanceCount: int, /) -> None: ...
        def setMeshResolution(self, resolution: PySide6.QtCore.QSize, /) -> None: ...
        def setMirrored(self, mirrored: bool, /) -> None: ...
        def setPrimitiveRestartEnabled(self, enabled: bool, /) -> None: ...
        def setPrimitiveType(self, primitiveType: PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer.PrimitiveType, /) -> None: ...
        def setRestartIndexValue(self, index: int, /) -> None: ...
        def setVertexCount(self, vertexCount: int, /) -> None: ...
        def setWidth(self, width: float, /) -> None: ...
        def width(self, /) -> float: ...

    class QSkyboxEntity(PySide6.Qt3DCore.Qt3DCore.QEntity):

        baseNameChanged          : typing.ClassVar[Signal] = ... # baseNameChanged(QString)
        extensionChanged         : typing.ClassVar[Signal] = ... # extensionChanged(QString)
        gammaCorrectEnabledChanged: typing.ClassVar[Signal] = ... # gammaCorrectEnabledChanged(bool)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, baseName: str | None = ..., extension: str | None = ..., gammaCorrect: bool | None = ...) -> None: ...

        def baseName(self, /) -> str: ...
        def extension(self, /) -> str: ...
        def isGammaCorrectEnabled(self, /) -> bool: ...
        def setBaseName(self, path: str, /) -> None: ...
        def setExtension(self, extension: str, /) -> None: ...
        def setGammaCorrectEnabled(self, enabled: bool, /) -> None: ...

    class QSphereGeometry(PySide6.Qt3DCore.Qt3DCore.QGeometry):

        generateTangentsChanged  : typing.ClassVar[Signal] = ... # generateTangentsChanged(bool)
        radiusChanged            : typing.ClassVar[Signal] = ... # radiusChanged(float)
        ringsChanged             : typing.ClassVar[Signal] = ... # ringsChanged(int)
        slicesChanged            : typing.ClassVar[Signal] = ... # slicesChanged(int)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, rings: int | None = ..., slices: int | None = ..., radius: float | None = ..., generateTangents: bool | None = ..., positionAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., normalAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., texCoordAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., tangentAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., indexAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ...) -> None: ...

        def generateTangents(self, /) -> bool: ...
        def indexAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def normalAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def positionAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def radius(self, /) -> float: ...
        def rings(self, /) -> int: ...
        def setGenerateTangents(self, gen: bool, /) -> None: ...
        def setRadius(self, radius: float, /) -> None: ...
        def setRings(self, rings: int, /) -> None: ...
        def setSlices(self, slices: int, /) -> None: ...
        def slices(self, /) -> int: ...
        def tangentAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def texCoordAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def updateIndices(self, /) -> None: ...
        def updateVertices(self, /) -> None: ...

    class QSphereGeometryView(PySide6.Qt3DCore.Qt3DCore.QGeometryView):

        generateTangentsChanged  : typing.ClassVar[Signal] = ... # generateTangentsChanged(bool)
        radiusChanged            : typing.ClassVar[Signal] = ... # radiusChanged(float)
        ringsChanged             : typing.ClassVar[Signal] = ... # ringsChanged(int)
        slicesChanged            : typing.ClassVar[Signal] = ... # slicesChanged(int)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, rings: int | None = ..., slices: int | None = ..., radius: float | None = ..., generateTangents: bool | None = ...) -> None: ...

        def generateTangents(self, /) -> bool: ...
        def radius(self, /) -> float: ...
        def rings(self, /) -> int: ...
        def setFirstInstance(self, firstInstance: int, /) -> None: ...
        def setGenerateTangents(self, gen: bool, /) -> None: ...
        def setGeometry(self, geometry: PySide6.Qt3DCore.Qt3DCore.QGeometry, /) -> None: ...
        def setIndexOffset(self, indexOffset: int, /) -> None: ...
        def setPrimitiveRestartEnabled(self, enabled: bool, /) -> None: ...
        def setPrimitiveType(self, primitiveType: PySide6.Qt3DCore.Qt3DCore.QGeometryView.PrimitiveType, /) -> None: ...
        def setRadius(self, radius: float, /) -> None: ...
        def setRestartIndexValue(self, index: int, /) -> None: ...
        def setRings(self, rings: int, /) -> None: ...
        def setSlices(self, slices: int, /) -> None: ...
        def setVertexCount(self, vertexCount: int, /) -> None: ...
        def slices(self, /) -> int: ...

    class QSphereMesh(PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer):

        generateTangentsChanged  : typing.ClassVar[Signal] = ... # generateTangentsChanged(bool)
        radiusChanged            : typing.ClassVar[Signal] = ... # radiusChanged(float)
        ringsChanged             : typing.ClassVar[Signal] = ... # ringsChanged(int)
        slicesChanged            : typing.ClassVar[Signal] = ... # slicesChanged(int)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, rings: int | None = ..., slices: int | None = ..., radius: float | None = ..., generateTangents: bool | None = ...) -> None: ...

        def generateTangents(self, /) -> bool: ...
        def radius(self, /) -> float: ...
        def rings(self, /) -> int: ...
        def setFirstInstance(self, firstInstance: int, /) -> None: ...
        def setGenerateTangents(self, gen: bool, /) -> None: ...
        def setGeometry(self, geometry: PySide6.Qt3DCore.Qt3DCore.QGeometry, /) -> None: ...
        def setIndexOffset(self, indexOffset: int, /) -> None: ...
        def setPrimitiveRestartEnabled(self, enabled: bool, /) -> None: ...
        def setPrimitiveType(self, primitiveType: PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer.PrimitiveType, /) -> None: ...
        def setRadius(self, radius: float, /) -> None: ...
        def setRestartIndexValue(self, index: int, /) -> None: ...
        def setRings(self, rings: int, /) -> None: ...
        def setSlices(self, slices: int, /) -> None: ...
        def setVertexCount(self, vertexCount: int, /) -> None: ...
        def slices(self, /) -> int: ...

    class QSpriteGrid(PySide6.Qt3DExtras.Qt3DExtras.QAbstractSpriteSheet):

        columnsChanged           : typing.ClassVar[Signal] = ... # columnsChanged(int)
        rowsChanged              : typing.ClassVar[Signal] = ... # rowsChanged(int)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, rows: int | None = ..., columns: int | None = ...) -> None: ...

        def columns(self, /) -> int: ...
        def rows(self, /) -> int: ...
        def setColumns(self, columns: int, /) -> None: ...
        def setRows(self, rows: int, /) -> None: ...

    class QSpriteSheet(PySide6.Qt3DExtras.Qt3DExtras.QAbstractSpriteSheet):

        spritesChanged           : typing.ClassVar[Signal] = ... # spritesChanged(QList<QSpriteSheetItem*>)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, sprites: collections.abc.Sequence[PySide6.Qt3DExtras.Qt3DExtras.QSpriteSheetItem] | None = ...) -> None: ...

        @typing.overload
        def addSprite(self, sprite: PySide6.Qt3DExtras.Qt3DExtras.QSpriteSheetItem, /) -> None: ...
        @typing.overload
        def addSprite(self, x: int, y: int, width: int, height: int, /) -> PySide6.Qt3DExtras.Qt3DExtras.QSpriteSheetItem: ...
        def removeSprite(self, sprite: PySide6.Qt3DExtras.Qt3DExtras.QSpriteSheetItem, /) -> None: ...
        def setSprites(self, sprites: collections.abc.Sequence[PySide6.Qt3DExtras.Qt3DExtras.QSpriteSheetItem], /) -> None: ...
        def sprites(self, /) -> typing.List[PySide6.Qt3DExtras.Qt3DExtras.QSpriteSheetItem]: ...

    class QSpriteSheetItem(PySide6.Qt3DCore.Qt3DCore.QNode):

        heightChanged            : typing.ClassVar[Signal] = ... # heightChanged(int)
        widthChanged             : typing.ClassVar[Signal] = ... # widthChanged(int)
        xChanged                 : typing.ClassVar[Signal] = ... # xChanged(int)
        yChanged                 : typing.ClassVar[Signal] = ... # yChanged(int)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, x: int | None = ..., y: int | None = ..., width: int | None = ..., height: int | None = ...) -> None: ...

        def height(self, /) -> int: ...
        def setHeight(self, height: int, /) -> None: ...
        def setWidth(self, width: int, /) -> None: ...
        def setX(self, x: int, /) -> None: ...
        def setY(self, y: int, /) -> None: ...
        def width(self, /) -> int: ...
        def x(self, /) -> int: ...
        def y(self, /) -> int: ...

    class QText2DEntity(PySide6.Qt3DCore.Qt3DCore.QEntity):

        colorChanged             : typing.ClassVar[Signal] = ... # colorChanged(QColor)
        fontChanged              : typing.ClassVar[Signal] = ... # fontChanged(QFont)
        heightChanged            : typing.ClassVar[Signal] = ... # heightChanged(float)
        textChanged              : typing.ClassVar[Signal] = ... # textChanged(QString)
        widthChanged             : typing.ClassVar[Signal] = ... # widthChanged(float)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, font: PySide6.QtGui.QFont | None = ..., text: str | None = ..., color: PySide6.QtGui.QColor | None = ..., width: float | None = ..., height: float | None = ..., alignment: PySide6.QtCore.Qt.AlignmentFlag | None = ...) -> None: ...

        def alignment(self, /) -> PySide6.QtCore.Qt.AlignmentFlag: ...
        def color(self, /) -> PySide6.QtGui.QColor: ...
        def font(self, /) -> PySide6.QtGui.QFont: ...
        def height(self, /) -> float: ...
        def setAlignment(self, alignment: PySide6.QtCore.Qt.AlignmentFlag, /) -> None: ...
        def setColor(self, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /) -> None: ...
        def setFont(self, font: PySide6.QtGui.QFont | str | collections.abc.Sequence[str], /) -> None: ...
        def setHeight(self, height: float, /) -> None: ...
        def setText(self, text: str, /) -> None: ...
        def setWidth(self, width: float, /) -> None: ...
        def text(self, /) -> str: ...
        def width(self, /) -> float: ...

    class QTextureMaterial(PySide6.Qt3DRender.Qt3DRender.QMaterial):

        alphaBlendingEnabledChanged: typing.ClassVar[Signal] = ... # alphaBlendingEnabledChanged(bool)
        textureChanged           : typing.ClassVar[Signal] = ... # textureChanged(Qt3DRender::QAbstractTexture*)
        textureOffsetChanged     : typing.ClassVar[Signal] = ... # textureOffsetChanged(QVector2D)
        textureTransformChanged  : typing.ClassVar[Signal] = ... # textureTransformChanged(QMatrix3x3)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, texture: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture | None = ..., textureOffset: PySide6.QtGui.QVector2D | None = ..., textureTransform: PySide6.QtGui.QMatrix3x3 | None = ..., alphaBlending: bool | None = ...) -> None: ...

        def isAlphaBlendingEnabled(self, /) -> bool: ...
        def setAlphaBlendingEnabled(self, enabled: bool, /) -> None: ...
        def setTexture(self, texture: PySide6.Qt3DRender.Qt3DRender.QAbstractTexture, /) -> None: ...
        def setTextureOffset(self, textureOffset: PySide6.QtGui.QVector2D, /) -> None: ...
        def setTextureTransform(self, matrix: PySide6.QtGui.QMatrix3x3, /) -> None: ...
        def texture(self, /) -> PySide6.Qt3DRender.Qt3DRender.QAbstractTexture: ...
        def textureOffset(self, /) -> PySide6.QtGui.QVector2D: ...
        def textureTransform(self, /) -> PySide6.QtGui.QMatrix3x3: ...

    class QTorusGeometry(PySide6.Qt3DCore.Qt3DCore.QGeometry):

        minorRadiusChanged       : typing.ClassVar[Signal] = ... # minorRadiusChanged(float)
        radiusChanged            : typing.ClassVar[Signal] = ... # radiusChanged(float)
        ringsChanged             : typing.ClassVar[Signal] = ... # ringsChanged(int)
        slicesChanged            : typing.ClassVar[Signal] = ... # slicesChanged(int)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, rings: int | None = ..., slices: int | None = ..., radius: float | None = ..., minorRadius: float | None = ..., positionAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., normalAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., texCoordAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ..., indexAttribute: PySide6.Qt3DCore.Qt3DCore.QAttribute | None = ...) -> None: ...

        def indexAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def minorRadius(self, /) -> float: ...
        def normalAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def positionAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def radius(self, /) -> float: ...
        def rings(self, /) -> int: ...
        def setMinorRadius(self, minorRadius: float, /) -> None: ...
        def setRadius(self, radius: float, /) -> None: ...
        def setRings(self, rings: int, /) -> None: ...
        def setSlices(self, slices: int, /) -> None: ...
        def slices(self, /) -> int: ...
        def texCoordAttribute(self, /) -> PySide6.Qt3DCore.Qt3DCore.QAttribute: ...
        def updateIndices(self, /) -> None: ...
        def updateVertices(self, /) -> None: ...

    class QTorusGeometryView(PySide6.Qt3DCore.Qt3DCore.QGeometryView):

        minorRadiusChanged       : typing.ClassVar[Signal] = ... # minorRadiusChanged(float)
        radiusChanged            : typing.ClassVar[Signal] = ... # radiusChanged(float)
        ringsChanged             : typing.ClassVar[Signal] = ... # ringsChanged(int)
        slicesChanged            : typing.ClassVar[Signal] = ... # slicesChanged(int)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, rings: int | None = ..., slices: int | None = ..., radius: float | None = ..., minorRadius: float | None = ...) -> None: ...

        def minorRadius(self, /) -> float: ...
        def radius(self, /) -> float: ...
        def rings(self, /) -> int: ...
        def setFirstInstance(self, firstInstance: int, /) -> None: ...
        def setGeometry(self, geometry: PySide6.Qt3DCore.Qt3DCore.QGeometry, /) -> None: ...
        def setIndexOffset(self, indexOffset: int, /) -> None: ...
        def setInstanceCount(self, instanceCount: int, /) -> None: ...
        def setMinorRadius(self, minorRadius: float, /) -> None: ...
        def setPrimitiveRestartEnabled(self, enabled: bool, /) -> None: ...
        def setPrimitiveType(self, primitiveType: PySide6.Qt3DCore.Qt3DCore.QGeometryView.PrimitiveType, /) -> None: ...
        def setRadius(self, radius: float, /) -> None: ...
        def setRestartIndexValue(self, index: int, /) -> None: ...
        def setRings(self, rings: int, /) -> None: ...
        def setSlices(self, slices: int, /) -> None: ...
        def setVertexCount(self, vertexCount: int, /) -> None: ...
        def slices(self, /) -> int: ...

    class QTorusMesh(PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer):

        minorRadiusChanged       : typing.ClassVar[Signal] = ... # minorRadiusChanged(float)
        radiusChanged            : typing.ClassVar[Signal] = ... # radiusChanged(float)
        ringsChanged             : typing.ClassVar[Signal] = ... # ringsChanged(int)
        slicesChanged            : typing.ClassVar[Signal] = ... # slicesChanged(int)

        def __init__(self, /, parent: PySide6.Qt3DCore.Qt3DCore.QNode | None = ..., *, rings: int | None = ..., slices: int | None = ..., radius: float | None = ..., minorRadius: float | None = ...) -> None: ...

        def minorRadius(self, /) -> float: ...
        def radius(self, /) -> float: ...
        def rings(self, /) -> int: ...
        def setFirstInstance(self, firstInstance: int, /) -> None: ...
        def setGeometry(self, geometry: PySide6.Qt3DCore.Qt3DCore.QGeometry, /) -> None: ...
        def setIndexOffset(self, indexOffset: int, /) -> None: ...
        def setInstanceCount(self, instanceCount: int, /) -> None: ...
        def setMinorRadius(self, minorRadius: float, /) -> None: ...
        def setPrimitiveRestartEnabled(self, enabled: bool, /) -> None: ...
        def setPrimitiveType(self, primitiveType: PySide6.Qt3DRender.Qt3DRender.QGeometryRenderer.PrimitiveType, /) -> None: ...
        def setRadius(self, radius: float, /) -> None: ...
        def setRestartIndexValue(self, index: int, /) -> None: ...
        def setRings(self, rings: int, /) -> None: ...
        def setSlices(self, slices: int, /) -> None: ...
        def setVertexCount(self, vertexCount: int, /) -> None: ...
        def slices(self, /) -> int: ...

    class Qt3DWindow(PySide6.QtGui.QWindow):

        def __init__(self, /, screen: PySide6.QtGui.QScreen | None = ..., arg__2: PySide6.Qt3DRender.Qt3DRender.API = ...) -> None: ...

        def activeFrameGraph(self, /) -> PySide6.Qt3DRender.Qt3DRender.QFrameGraphNode: ...
        def camera(self, /) -> PySide6.Qt3DRender.Qt3DRender.QCamera: ...
        def defaultFrameGraph(self, /) -> PySide6.Qt3DExtras.Qt3DExtras.QForwardRenderer: ...
        def event(self, e: PySide6.QtCore.QEvent, /) -> bool: ...
        @typing.overload
        def registerAspect(self, aspect: PySide6.Qt3DCore.Qt3DCore.QAbstractAspect, /) -> None: ...
        @typing.overload
        def registerAspect(self, name: str, /) -> None: ...
        def renderSettings(self, /) -> PySide6.Qt3DRender.Qt3DRender.QRenderSettings: ...
        def resizeEvent(self, arg__1: PySide6.QtGui.QResizeEvent, /) -> None: ...
        def setActiveFrameGraph(self, activeFrameGraph: PySide6.Qt3DRender.Qt3DRender.QFrameGraphNode, /) -> None: ...
        def setRootEntity(self, root: PySide6.Qt3DCore.Qt3DCore.QEntity, /) -> None: ...
        def showEvent(self, e: PySide6.QtGui.QShowEvent, /) -> None: ...


    @staticmethod
    def setupWindowSurface(window: PySide6.QtGui.QWindow, arg__2: PySide6.Qt3DRender.Qt3DRender.API, /) -> None: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof
